/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DL3Y.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DL3Y *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DL3Y_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DL3Y();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DL3Y::Heavy_WSTD_DL3Y(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_2oA7sfgm);
  numBytes += sLine_init(&sLine_TuY09ETd);
  numBytes += sLine_init(&sLine_IhnTv8SQ);
  numBytes += sLine_init(&sLine_yE9H23On);
  numBytes += sLine_init(&sLine_Q9FHUFOi);
  numBytes += sBiquad_init(&sBiquad_s_4QgyLqtB);
  numBytes += sLine_init(&sLine_NCEp5pmf);
  numBytes += sLine_init(&sLine_Ep6UuHZl);
  numBytes += sLine_init(&sLine_pI6D5OD0);
  numBytes += sLine_init(&sLine_rMu40C5n);
  numBytes += sBiquad_init(&sBiquad_s_tzcFH2Gv);
  numBytes += sLine_init(&sLine_593uHNv0);
  numBytes += sLine_init(&sLine_twYcT8JJ);
  numBytes += sLine_init(&sLine_38198bpS);
  numBytes += sLine_init(&sLine_0Nt6SWVX);
  numBytes += sLine_init(&sLine_b3c8LHzh);
  numBytes += sBiquad_init(&sBiquad_s_G5nYmyjp);
  numBytes += sLine_init(&sLine_E2Gpf6sL);
  numBytes += sLine_init(&sLine_HiuaC8y2);
  numBytes += sLine_init(&sLine_bvFDyvHj);
  numBytes += sLine_init(&sLine_0MKEaSrz);
  numBytes += sLine_init(&sLine_dTwWljtH);
  numBytes += sBiquad_init(&sBiquad_s_Wo6E04Vt);
  numBytes += sLine_init(&sLine_M6v7dLaC);
  numBytes += sLine_init(&sLine_3q34eYtg);
  numBytes += sLine_init(&sLine_NVKNfUn9);
  numBytes += sLine_init(&sLine_qOgan6NH);
  numBytes += sBiquad_init(&sBiquad_s_LSKdzBzM);
  numBytes += sLine_init(&sLine_WkngJ3XO);
  numBytes += sLine_init(&sLine_xZqgTfuT);
  numBytes += sLine_init(&sLine_1FHfXI1L);
  numBytes += sLine_init(&sLine_NBRfdjRL);
  numBytes += sLine_init(&sLine_JSqxpaNw);
  numBytes += sBiquad_init(&sBiquad_s_pUCSPQWX);
  numBytes += sLine_init(&sLine_bLCuxmoW);
  numBytes += sTabread_init(&sTabread_yLdSjCoK, &hTable_Tdkvhk3y, true);
  numBytes += sLine_init(&sLine_utSKmGDg);
  numBytes += sLine_init(&sLine_wfxUkuYD);
  numBytes += sTabread_init(&sTabread_jTcBTZVp, &hTable_dWUBVXGP, true);
  numBytes += sLine_init(&sLine_Twvj8aKn);
  numBytes += sRPole_init(&sRPole_mVWAUj7v);
  numBytes += sDel1_init(&sDel1_4WS56Rl5);
  numBytes += sTabwrite_init(&sTabwrite_PZ0ghr0m, &hTable_Tdkvhk3y);
  numBytes += sRPole_init(&sRPole_EcWtrgoa);
  numBytes += sDel1_init(&sDel1_8FaApGNr);
  numBytes += sTabwrite_init(&sTabwrite_WF3ks5yU, &hTable_dWUBVXGP);
  numBytes += sLine_init(&sLine_4IuQTbbn);
  numBytes += sLine_init(&sLine_iHsKI804);
  numBytes += sRPole_init(&sRPole_1oFsDUID);
  numBytes += sEnv_init(&sEnv_4qogAbA2, 1024, 512);
  numBytes += sRPole_init(&sRPole_uUWeBaaJ);
  numBytes += sLine_init(&sLine_IQ7inc5L);
  numBytes += sLine_init(&sLine_oGq0VDwP);
  numBytes += sRPole_init(&sRPole_Cud2Lm2t);
  numBytes += sEnv_init(&sEnv_K4IbXxoc, 1024, 512);
  numBytes += sRPole_init(&sRPole_J4RXl7aQ);
  numBytes += sLine_init(&sLine_8iVM7Tlz);
  numBytes += sTabread_init(&sTabread_mvrlFkTa, &hTable_ExmUbeIJ, true);
  numBytes += sLine_init(&sLine_Fb3CgQop);
  numBytes += sLine_init(&sLine_MMX20r1Q);
  numBytes += sTabread_init(&sTabread_bq6wfG3C, &hTable_JQ53cYuw, true);
  numBytes += sLine_init(&sLine_tD2vcfSh);
  numBytes += sRPole_init(&sRPole_pbZ8NXDL);
  numBytes += sDel1_init(&sDel1_Hfm0T8aS);
  numBytes += sTabwrite_init(&sTabwrite_6jewWSxb, &hTable_ExmUbeIJ);
  numBytes += sRPole_init(&sRPole_S8KxYp5s);
  numBytes += sDel1_init(&sDel1_svi7Odcn);
  numBytes += sTabwrite_init(&sTabwrite_xqQF5wro, &hTable_JQ53cYuw);
  numBytes += sLine_init(&sLine_miEqcGzl);
  numBytes += sLine_init(&sLine_kJnqDVux);
  numBytes += sRPole_init(&sRPole_4fd8yj2X);
  numBytes += sEnv_init(&sEnv_UKnxZEUt, 1024, 512);
  numBytes += sRPole_init(&sRPole_KnLzsVKf);
  numBytes += sLine_init(&sLine_Bnrp9H72);
  numBytes += sLine_init(&sLine_jaKaOK2j);
  numBytes += sRPole_init(&sRPole_LWgkhv6F);
  numBytes += sEnv_init(&sEnv_9KD2wR6y, 1024, 512);
  numBytes += sRPole_init(&sRPole_mb7JcPub);
  numBytes += sLine_init(&sLine_URkDQfHZ);
  numBytes += sTabread_init(&sTabread_dlR63vCu, &hTable_DmQuzStW, true);
  numBytes += sLine_init(&sLine_eOJnaWpJ);
  numBytes += sLine_init(&sLine_IqdsTprS);
  numBytes += sTabread_init(&sTabread_99Js78VF, &hTable_g879XfQC, true);
  numBytes += sLine_init(&sLine_Fkm2zs7P);
  numBytes += sRPole_init(&sRPole_vuxVlLff);
  numBytes += sDel1_init(&sDel1_UpuHiHui);
  numBytes += sTabwrite_init(&sTabwrite_zFlFCvWn, &hTable_DmQuzStW);
  numBytes += sRPole_init(&sRPole_mj1o6jcU);
  numBytes += sDel1_init(&sDel1_ihbWM3u9);
  numBytes += sTabwrite_init(&sTabwrite_VXpSlNKB, &hTable_g879XfQC);
  numBytes += sLine_init(&sLine_0OcbbiF9);
  numBytes += sLine_init(&sLine_fLPL752l);
  numBytes += sRPole_init(&sRPole_BXVafAk2);
  numBytes += sEnv_init(&sEnv_jtn9H55R, 1024, 512);
  numBytes += sRPole_init(&sRPole_xMqUgu9F);
  numBytes += sLine_init(&sLine_x7HYKtqm);
  numBytes += sLine_init(&sLine_mgVqi2NH);
  numBytes += sRPole_init(&sRPole_c9OVUOot);
  numBytes += sEnv_init(&sEnv_4e45RP5Y, 1024, 512);
  numBytes += sRPole_init(&sRPole_hzYACccr);
  numBytes += cVar_init_f(&cVar_cxxQrLLv, 0.0f);
  numBytes += cVar_init_f(&cVar_M1BElmmi, 0.0f);
  numBytes += cVar_init_f(&cVar_4CCMkPuF, 0.0f);
  numBytes += cVar_init_f(&cVar_M099If1F, 0.0f);
  numBytes += cSlice_init(&cSlice_LyZgYwjs, 1, -1);
  numBytes += cVar_init_f(&cVar_DCAGpsrt, 1337.0f);
  numBytes += cVar_init_f(&cVar_mQZfrxjo, 0.0f);
  numBytes += cIf_init(&cIf_lL1fHdyC, false);
  numBytes += cIf_init(&cIf_cZA12R40, false);
  numBytes += cBinop_init(&cBinop_O6VJLiVF, 0.0f); // __pow
  numBytes += cIf_init(&cIf_LyuB0eKp, false);
  numBytes += cBinop_init(&cBinop_Ke0u078J, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_A7RHhWvn, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_RSChAT3j, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_n6WLH7zP, 0.0f);
  numBytes += cIf_init(&cIf_iV0dq44k, false);
  numBytes += cIf_init(&cIf_f2UBLz1U, false);
  numBytes += cBinop_init(&cBinop_7vmtFT0a, 0.0f); // __pow
  numBytes += cIf_init(&cIf_ZGIXDThq, false);
  numBytes += cBinop_init(&cBinop_AsRZZ4Ka, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Lwl5NuNM, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_pN4RM8Kn, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_XUYoBd2C, 0.0f);
  numBytes += cIf_init(&cIf_eMpVu2Ga, false);
  numBytes += cIf_init(&cIf_4q8GxnWe, false);
  numBytes += cBinop_init(&cBinop_oOQ1JgQL, 0.0f); // __pow
  numBytes += cIf_init(&cIf_UNwDak3N, false);
  numBytes += cBinop_init(&cBinop_paaiBBkN, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_EXfduDmK, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_3KDtpQLo, -15.0f); // __eq
  numBytes += cIf_init(&cIf_7WCnghxb, false);
  numBytes += cSlice_init(&cSlice_XZnYvNV6, 1, -1);
  numBytes += cVar_init_f(&cVar_SI82aWPG, 0.0f);
  numBytes += cSlice_init(&cSlice_CKdRU5sG, 1, -1);
  numBytes += cVar_init_f(&cVar_GNuuymJh, 0.0f);
  numBytes += cSlice_init(&cSlice_FSGXAGDn, 1, -1);
  numBytes += cVar_init_f(&cVar_Z3k4yrjR, 0.0f);
  numBytes += cSlice_init(&cSlice_xuVQVVS1, 1, -1);
  numBytes += cVar_init_f(&cVar_DWSAn3xD, 0.313f);
  numBytes += cBinop_init(&cBinop_cPIbvZSo, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_FooeIsxx, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_4KOoNUSH, 0.0f);
  numBytes += cVar_init_f(&cVar_8RY5oQ5q, 1337.0f);
  numBytes += cVar_init_f(&cVar_rHKqaPy8, 0.3f);
  numBytes += cBinop_init(&cBinop_LmoUtc4k, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dHaRxvNO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_USdkIcII, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4eiPbojW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tiyGTEOR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rzVyBGxR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qPlAavvp, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_NIAXR70u, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_n98WZNDD, 0.0f);
  numBytes += cVar_init_f(&cVar_6fse0yqs, 1337.0f);
  numBytes += cVar_init_f(&cVar_rPLqoEcb, 0.313f);
  numBytes += cBinop_init(&cBinop_JfndkYEu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_51ekKGyS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YUlFJ4eu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_532v9AMv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jeGJ546x, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iwAMzmYW, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_VENQ3jPZ, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_wRMa5j8D, 0.0f);
  numBytes += cVar_init_f(&cVar_m2MMB7lY, 1037.0f);
  numBytes += cVar_init_f(&cVar_UJg40Vzs, 0.4f);
  numBytes += cBinop_init(&cBinop_BxrOejqu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1oDyPN7x, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gsNBelOe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bLUthpNQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_CEgnlP8u, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7GSVYeUz, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_jwVmV3J4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vrczjGTs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_T4VZ0KYY, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_wMzOzRuV, 1, -1);
  numBytes += cVar_init_f(&cVar_6RiZ01OC, 1337.0f);
  numBytes += cVar_init_f(&cVar_mXCCbJU8, 0.0f);
  numBytes += cIf_init(&cIf_NRaa6QmT, false);
  numBytes += cIf_init(&cIf_qBaOlj99, false);
  numBytes += cBinop_init(&cBinop_gq3zWd7R, 0.0f); // __pow
  numBytes += cIf_init(&cIf_ZoptMGH3, false);
  numBytes += cBinop_init(&cBinop_7dcKq2fK, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_PkAaE755, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_6zP3N03w, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_ds3Y0ZbT, 0.0f);
  numBytes += cIf_init(&cIf_dwkA167N, false);
  numBytes += cIf_init(&cIf_bSH1jJnF, false);
  numBytes += cBinop_init(&cBinop_kqzZ9Dhe, 0.0f); // __pow
  numBytes += cIf_init(&cIf_7RFJm1ji, false);
  numBytes += cBinop_init(&cBinop_1fcRT3cL, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_1qVFACP1, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Uxv1lE2r, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_eEkNIBET, 0.0f);
  numBytes += cIf_init(&cIf_QFefm8yF, false);
  numBytes += cIf_init(&cIf_LJLJDizT, false);
  numBytes += cBinop_init(&cBinop_nogIiuYI, 0.0f); // __pow
  numBytes += cIf_init(&cIf_CThr5J1N, false);
  numBytes += cBinop_init(&cBinop_qVLWz643, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_qb4vMCS7, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_9WQ63N2J, -15.0f); // __eq
  numBytes += cIf_init(&cIf_34M4KyqF, false);
  numBytes += cSlice_init(&cSlice_eeavX0dz, 1, -1);
  numBytes += cVar_init_f(&cVar_pfN4GjrM, 0.0f);
  numBytes += cSlice_init(&cSlice_ze9Dm9Fr, 1, -1);
  numBytes += cVar_init_f(&cVar_ittQyS7t, 0.0f);
  numBytes += cSlice_init(&cSlice_kUkHa0E6, 1, -1);
  numBytes += cVar_init_f(&cVar_P9pvGXEH, 0.0f);
  numBytes += cSlice_init(&cSlice_KLnEO0Nh, 1, -1);
  numBytes += cVar_init_f(&cVar_WArCMriK, 0.313f);
  numBytes += cBinop_init(&cBinop_PhHIlBSm, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_5QO47nES, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_GdlDbBkg, 0.0f);
  numBytes += cVar_init_f(&cVar_dbniPqPi, 1337.0f);
  numBytes += cVar_init_f(&cVar_LoTZQOlp, 0.3f);
  numBytes += cBinop_init(&cBinop_p0MimApN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xUMeshZl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rsCrb6Re, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JvULyDzm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NVcHqk2H, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_VS70miQL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OGRdbRlk, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_haehmiWM, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_2UbxGgbJ, 0.0f);
  numBytes += cVar_init_f(&cVar_OcT4AKvb, 1337.0f);
  numBytes += cVar_init_f(&cVar_HRfw6K6g, 0.313f);
  numBytes += cBinop_init(&cBinop_UaNq6Kvq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xkW1VZvY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2I4vuqhv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Zf2eb50X, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Z5xDvD5e, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Z6ibeN3d, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_kcYgMfwV, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_atW42VWY, 0.0f);
  numBytes += cVar_init_f(&cVar_aWiIfSwa, 1037.0f);
  numBytes += cVar_init_f(&cVar_OP2sDIRG, 0.4f);
  numBytes += cBinop_init(&cBinop_dVlqQS01, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_hduPcjXo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FAduSLdn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6kr0ULS3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zY7Is4WI, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0T2boKRP, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_jDCQyZo4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_V4kp1T7G, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Zi9H2KQy, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_xnzvPWWJ, 5705.6f);
  numBytes += cVar_init_f(&cVar_R4iBnpQY, 313.3f);
  numBytes += cBinop_init(&cBinop_U5Yl6zU5, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_BdH9ivmz, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_qHMSS57v, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_T5QgclAM, 0.0f);
  numBytes += cVar_init_f(&cVar_0ddi3Qld, 0.0f);
  numBytes += cVar_init_f(&cVar_0VWzsqzE, 0.0f);
  numBytes += cVar_init_f(&cVar_94kfXfc5, 0.0f);
  numBytes += cVar_init_f(&cVar_e6Fatjfe, 0.0f);
  numBytes += cVar_init_f(&cVar_n6r9BSz5, 0.0f);
  numBytes += cVar_init_f(&cVar_lbSAm9zV, 0.0f);
  numBytes += cVar_init_f(&cVar_hMkDTYQJ, 0.0f);
  numBytes += cVar_init_f(&cVar_hGaBYCEt, 0.0f);
  numBytes += cVar_init_f(&cVar_wcXCsTCN, 0.0f);
  numBytes += cVar_init_f(&cVar_W4DERNiU, 0.0f);
  numBytes += cVar_init_f(&cVar_lLrbhtQi, 0.0f);
  numBytes += cSlice_init(&cSlice_TTSKtLhm, 1, -1);
  numBytes += cVar_init_f(&cVar_mETmPcNZ, 0.5f);
  numBytes += cSlice_init(&cSlice_7zTFFsW4, 1, -1);
  numBytes += cVar_init_f(&cVar_xkyb6vYx, 0.2f);
  numBytes += cSlice_init(&cSlice_9sw92gbO, 1, -1);
  numBytes += cVar_init_f(&cVar_GHhzdfso, 500.0f);
  numBytes += sVarf_init(&sVarf_CSIs9fAK, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_T8mSP6iT, 600.0f);
  numBytes += cBinop_init(&cBinop_ae3TMMZt, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_HM6GvIZJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tQiURUs4, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_bhwpJze7, 600.0f);
  numBytes += cBinop_init(&cBinop_diWaZVJ6, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_qIxhJsgt, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_m99HuQL2, 4000.0f);
  numBytes += cBinop_init(&cBinop_7lUGePv0, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_ljKnGqT9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YMO7IlEL, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_8gafSZCk, 4000.0f);
  numBytes += cBinop_init(&cBinop_2Y86FPIU, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_v0ldGHEL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PDhT2aip, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_TFNaY7dv, false);
  numBytes += cBinop_init(&cBinop_gTFQmZF3, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_Hx7wVEbO, 20.0f);
  numBytes += cBinop_init(&cBinop_5guEBplm, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_wa34A2tM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_71QveUuE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_INsMxYSg, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_72HndWDZ, false);
  numBytes += cBinop_init(&cBinop_rXKQbkBQ, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_8f3Pqlc4, 20.0f);
  numBytes += cBinop_init(&cBinop_nBqiqbq5, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_GMP0WMNK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pmMLYMUx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pn9tKd06, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_zz3SbW4j, 1, -1);
  numBytes += cVar_init_f(&cVar_s9NX3qqo, 0.25f);
  numBytes += cDelay_init(this, &cDelay_MUzkcSJA, 0.0f);
  numBytes += cDelay_init(this, &cDelay_hFg83igd, 0.0f);
  numBytes += hTable_init(&hTable_Tdkvhk3y, 256);
  numBytes += cTabhead_init(&cTabhead_gJx0X160, &hTable_Tdkvhk3y);
  numBytes += cVar_init_s(&cVar_rg6DXSsy, "del-1349-delayL");
  numBytes += cDelay_init(this, &cDelay_mehR0ZRO, 0.0f);
  numBytes += cDelay_init(this, &cDelay_PKhlc9gf, 0.0f);
  numBytes += cBinop_init(&cBinop_0vHEpVN8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7JzSlYeh, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_FnTNBUuf, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_iyxFZsNq, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_WbOi1IDA, 0.0f);
  numBytes += cDelay_init(this, &cDelay_1QwPkM3X, 0.0f);
  numBytes += hTable_init(&hTable_dWUBVXGP, 256);
  numBytes += cTabhead_init(&cTabhead_o948jWOb, &hTable_dWUBVXGP);
  numBytes += cVar_init_s(&cVar_6UmO9q3a, "del-1349-delayR");
  numBytes += cDelay_init(this, &cDelay_9rsSqxY5, 0.0f);
  numBytes += cDelay_init(this, &cDelay_muWfJ5Ta, 0.0f);
  numBytes += cBinop_init(&cBinop_mtq9595T, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vVbf8fD4, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_uuyfjePH, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_wpy9S4O9, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_zEA4zm8f, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_P1YMH5Wi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fU6PD9Tj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MKbXnxjZ, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_C2bFMQDM, 1, -1);
  numBytes += cVar_init_f(&cVar_ojruipJx, 0.5f);
  numBytes += cSlice_init(&cSlice_SHnXfSmX, 1, -1);
  numBytes += cVar_init_f(&cVar_aP6sP9Af, 0.2f);
  numBytes += cSlice_init(&cSlice_FOt4HiNI, 1, -1);
  numBytes += cVar_init_f(&cVar_aCG7YvSd, 500.0f);
  numBytes += sVarf_init(&sVarf_PKwPEX0I, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_IxkAjUtR, 600.0f);
  numBytes += cBinop_init(&cBinop_88yn1poG, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_HvySZ8kd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cGNxohQa, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_T6BQO7pv, 600.0f);
  numBytes += cBinop_init(&cBinop_l9KhrgzD, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_K2hlnLN3, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_5wHoJyT6, 4000.0f);
  numBytes += cBinop_init(&cBinop_2Wxp9foq, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_2XIPchpG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_j1bSQNEb, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_G6DZUdJX, 4000.0f);
  numBytes += cBinop_init(&cBinop_IwyuYkjY, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_t9J0x4Lq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fQAyb3if, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_D6YE0FKL, false);
  numBytes += cBinop_init(&cBinop_8FlYGX1D, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_06Jdk9i8, 20.0f);
  numBytes += cBinop_init(&cBinop_4Ntd1sT1, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_jIJJgEol, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oroFNGcd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2cH5tQpI, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_kBbDWfrZ, false);
  numBytes += cBinop_init(&cBinop_QHGsMQaE, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_79mHy3TD, 20.0f);
  numBytes += cBinop_init(&cBinop_HqhktPo2, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_yFeKyiFF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_apWh2XYR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ceX3I6Pm, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_ZzoIGJiu, 1, -1);
  numBytes += cVar_init_f(&cVar_FEBZkrUM, 0.25f);
  numBytes += cDelay_init(this, &cDelay_It2DQ3al, 0.0f);
  numBytes += cDelay_init(this, &cDelay_2RHdwjE6, 0.0f);
  numBytes += hTable_init(&hTable_ExmUbeIJ, 256);
  numBytes += cTabhead_init(&cTabhead_2pTjEii2, &hTable_ExmUbeIJ);
  numBytes += cVar_init_s(&cVar_HwvrKiZy, "del-1428-delayL");
  numBytes += cDelay_init(this, &cDelay_W4P0Bzyf, 0.0f);
  numBytes += cDelay_init(this, &cDelay_6frF5PaN, 0.0f);
  numBytes += cBinop_init(&cBinop_WvArmTSc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4IQtwCC7, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_UQkR7FyD, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_LBqsb6y0, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_w42nRnWh, 0.0f);
  numBytes += cDelay_init(this, &cDelay_FpLWQE9o, 0.0f);
  numBytes += hTable_init(&hTable_JQ53cYuw, 256);
  numBytes += cTabhead_init(&cTabhead_FUifxdjL, &hTable_JQ53cYuw);
  numBytes += cVar_init_s(&cVar_jMqXPRBZ, "del-1428-delayR");
  numBytes += cDelay_init(this, &cDelay_C0ZoZRZz, 0.0f);
  numBytes += cDelay_init(this, &cDelay_AG1d21aw, 0.0f);
  numBytes += cBinop_init(&cBinop_3keyEG44, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ENff13kt, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_ONsXkYzG, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_a0LFPGxO, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_bofiRoCj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2ehm8OhQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RUl9SJo5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7wyCy6c9, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_y7q8YURr, 1, -1);
  numBytes += cVar_init_f(&cVar_z3nozhED, 0.5f);
  numBytes += cSlice_init(&cSlice_1nObwOGU, 1, -1);
  numBytes += cVar_init_f(&cVar_8ta5rOTh, 0.2f);
  numBytes += cSlice_init(&cSlice_pPHX2kaM, 1, -1);
  numBytes += cVar_init_f(&cVar_ennIrtAO, 500.0f);
  numBytes += sVarf_init(&sVarf_jmd58Q9e, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_wETjFAOW, 600.0f);
  numBytes += cBinop_init(&cBinop_Kdp7DS42, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_I5IjzmZh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CHIUgKtc, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_U3tCEwTp, 600.0f);
  numBytes += cBinop_init(&cBinop_xNxHPKNZ, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_5kqZopWZ, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_gI6eCAop, 4000.0f);
  numBytes += cBinop_init(&cBinop_icjT6bh1, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Ppdm7b6C, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6N9xixoS, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_khRxwZYA, 4000.0f);
  numBytes += cBinop_init(&cBinop_aLMRAXNc, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_2nTN6fGk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0LbwuWxx, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_dWzAIAQT, false);
  numBytes += cBinop_init(&cBinop_ySYnt1lD, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_X4B58Xcp, 20.0f);
  numBytes += cBinop_init(&cBinop_jZvAe5hb, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_IZBsLiYf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FkJRdlvA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_E8WGpvdP, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_JjZEs06u, false);
  numBytes += cBinop_init(&cBinop_tt2wlCFL, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_a8WDOYXA, 20.0f);
  numBytes += cBinop_init(&cBinop_QJPFh2wl, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_9oIIFQlZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4MgL4vKE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TPjdyPHS, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_YX0Spn8y, 1, -1);
  numBytes += cVar_init_f(&cVar_OGdAaZmD, 0.25f);
  numBytes += cDelay_init(this, &cDelay_6Jt0odZb, 0.0f);
  numBytes += cDelay_init(this, &cDelay_kJa7jeEw, 0.0f);
  numBytes += hTable_init(&hTable_DmQuzStW, 256);
  numBytes += cTabhead_init(&cTabhead_ykw58UG0, &hTable_DmQuzStW);
  numBytes += cVar_init_s(&cVar_BQDWME4k, "del-1507-delayL");
  numBytes += cDelay_init(this, &cDelay_fUcNu2hR, 0.0f);
  numBytes += cDelay_init(this, &cDelay_dRsZqUJx, 0.0f);
  numBytes += cBinop_init(&cBinop_0BGtaNGi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rWipsGoS, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_Lbph2uJj, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_JULe2pX5, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_CLJq33tF, 0.0f);
  numBytes += cDelay_init(this, &cDelay_WFtsTgmu, 0.0f);
  numBytes += hTable_init(&hTable_g879XfQC, 256);
  numBytes += cTabhead_init(&cTabhead_3g3CQxeW, &hTable_g879XfQC);
  numBytes += cVar_init_s(&cVar_tKu2rfdg, "del-1507-delayR");
  numBytes += cDelay_init(this, &cDelay_AjEqvswW, 0.0f);
  numBytes += cDelay_init(this, &cDelay_6hikNmJS, 0.0f);
  numBytes += cBinop_init(&cBinop_U557CEPr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iUwBd6V0, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_aV0zlqWv, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_WvkM6ASI, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_0C1haSB8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3QKCgs2s, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3Kgcf9t5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KGd2UF1k, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_pRG0OfjE, 1.0f);
  numBytes += cIf_init(&cIf_DUYmtJAs, false);
  numBytes += cIf_init(&cIf_8b8XU3gr, false);
  numBytes += cVar_init_f(&cVar_kmQQXUnd, 0.0f);
  numBytes += cVar_init_f(&cVar_VHTQOXFX, 0.0f);
  numBytes += cVar_init_f(&cVar_CCRFu9ju, 1.0f);
  numBytes += cIf_init(&cIf_yoSjmVvg, false);
  numBytes += cIf_init(&cIf_1z4OrrVx, false);
  numBytes += cVar_init_f(&cVar_wLiHOiSv, 0.0f);
  numBytes += cVar_init_f(&cVar_fAHXgocj, 0.0f);
  numBytes += cVar_init_f(&cVar_S4gmapW3, 1.0f);
  numBytes += cIf_init(&cIf_Ho6LZp4F, false);
  numBytes += cIf_init(&cIf_T1r9vE6w, false);
  numBytes += cVar_init_f(&cVar_Pdwn4J3F, 0.0f);
  numBytes += cVar_init_f(&cVar_LwxuYIQx, 0.0f);
  numBytes += cVar_init_f(&cVar_CEjjQhBW, 60000.0f);
  numBytes += cVar_init_f(&cVar_MXBEdkKs, 500.0f);
  numBytes += cSlice_init(&cSlice_thp5J8zs, 1, -1);
  numBytes += cSlice_init(&cSlice_f7RE54SZ, 1, -1);
  numBytes += cVar_init_f(&cVar_imrb104C, 0.0f);
  numBytes += cIf_init(&cIf_ZKrLSV0i, false);
  numBytes += cBinop_init(&cBinop_nYl5QiIs, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_CCbN6szz, 120.0f);
  numBytes += cBinop_init(&cBinop_WwL5Rbe8, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_yTGaFW7g, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_60JmJSYe, 60000.0f);
  numBytes += cVar_init_f(&cVar_yK5HW2gy, 500.0f);
  numBytes += cSlice_init(&cSlice_qeh5wPst, 1, -1);
  numBytes += cSlice_init(&cSlice_XUTgxZKR, 1, -1);
  numBytes += cVar_init_f(&cVar_wDB4J7lp, 0.0f);
  numBytes += cIf_init(&cIf_dcD6CUhi, false);
  numBytes += cBinop_init(&cBinop_ClIFezc2, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_nUlc5jzB, 120.0f);
  numBytes += cBinop_init(&cBinop_ykWyMoLz, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_Ao4VTc2n, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_KJi7WrH8, 60000.0f);
  numBytes += cVar_init_f(&cVar_yuO0Ev5b, 500.0f);
  numBytes += cSlice_init(&cSlice_ORoUioop, 1, -1);
  numBytes += cSlice_init(&cSlice_AnwqnjYb, 1, -1);
  numBytes += cVar_init_f(&cVar_PbilmJKv, 0.0f);
  numBytes += cIf_init(&cIf_ZnbNOHif, false);
  numBytes += cBinop_init(&cBinop_ocdcmFBs, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_DG9tLeJV, 120.0f);
  numBytes += cBinop_init(&cBinop_N8TFvabB, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_VlDOSGAL, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_A21pHe27, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NJ1KRqDS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rG4lDGZP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_n7vtT88R, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XAc2Lnuu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KQSv8Cir, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dZ936Rpt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_v6j5S1Fz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_v4k8uZS7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bNeGPnx2, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DL3Y::~Heavy_WSTD_DL3Y() {
  sEnv_free(&sEnv_4qogAbA2);
  sEnv_free(&sEnv_K4IbXxoc);
  sEnv_free(&sEnv_UKnxZEUt);
  sEnv_free(&sEnv_9KD2wR6y);
  sEnv_free(&sEnv_jtn9H55R);
  sEnv_free(&sEnv_4e45RP5Y);
  hTable_free(&hTable_Tdkvhk3y);
  hTable_free(&hTable_dWUBVXGP);
  hTable_free(&hTable_ExmUbeIJ);
  hTable_free(&hTable_JQ53cYuw);
  hTable_free(&hTable_DmQuzStW);
  hTable_free(&hTable_g879XfQC);
}

HvTable *Heavy_WSTD_DL3Y::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x29B74AF: return &hTable_Tdkvhk3y; // del-1349-delayL
    case 0x19A00729: return &hTable_dWUBVXGP; // del-1349-delayR
    case 0x584C8281: return &hTable_ExmUbeIJ; // del-1428-delayL
    case 0x54BF59F6: return &hTable_JQ53cYuw; // del-1428-delayR
    case 0xBCE693A: return &hTable_DmQuzStW; // del-1507-delayL
    case 0x95A380B3: return &hTable_g879XfQC; // del-1507-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DL3Y::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pu2NoPBG_sendMessage);
      break;
    }
    case 0xBB584857: { // High_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2EiNnxcf_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Dxyr87GA_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_caLDETxu_sendMessage);
      break;
    }
    case 0xDD62B09F: { // High_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xZALtXPv_sendMessage);
      break;
    }
    case 0xABB0CBCF: { // High_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Q1JYv1GU_sendMessage);
      break;
    }
    case 0xAE942A2: { // High_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uIliMSUo_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iYe1Ziz8_sendMessage);
      break;
    }
    case 0xA2D68920: { // Low_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yhdjANac_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dBO79Iav_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gwKD8tF1_sendMessage);
      break;
    }
    case 0xFFFEE96: { // Low_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_J9UxkRUV_sendMessage);
      break;
    }
    case 0xA3BD8A20: { // Low_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WBG84f72_sendMessage);
      break;
    }
    case 0x67F58CFB: { // Low_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jYsnJT2b_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qCmM9SR6_sendMessage);
      break;
    }
    case 0x59607D3: { // Mid_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eo61LnEd_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4J07busq_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_r26P1mbo_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_m8sXm888_sendMessage);
      break;
    }
    case 0x96E19510: { // Mid_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ORRH7ss3_sendMessage);
      break;
    }
    case 0xE1DB1774: { // Mid_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sfDctFH1_sendMessage);
      break;
    }
    case 0xDB67B94E: { // Mid_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aXaphhfq_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hbh2o6hq_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CspsPfOP_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xYyoMlcg_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LHmAyIjr_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XP7CqH2d_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_moFlU1mO_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MeacDDta_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Nf01sc3Y_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Jrgh0QzV_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wQjsqamu_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DY7VUTfA_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_i3yNzgeI_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Tb36u82i_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qqaNsAcw_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1iChQWl5_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NinU2bsY_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QYwrIzxp_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_anGDLL73_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tQHMpFjK_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sj19YkBv_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SWBJm4AX_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5NBDj3wk_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Q5yKSL6P_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_K0R5fp0h_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VLnWl3lw_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5whLPSVi_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oVtv3ZMi_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tFWWhnEU_sendMessage);
      break;
    }
    case 0x9FC1C9E5: { // 1349-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xkF4puXG_sendMessage);
      break;
    }
    case 0x5D7BD4E9: { // 1349-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dPx8wTm8_sendMessage);
      break;
    }
    case 0x371A347A: { // 1349-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZvnMWcNk_sendMessage);
      break;
    }
    case 0x810E74BC: { // 1349-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XomccZhE_sendMessage);
      break;
    }
    case 0xCC56B3CF: { // 1428-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wv7AMngu_sendMessage);
      break;
    }
    case 0x499A953B: { // 1428-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nxasNClf_sendMessage);
      break;
    }
    case 0xE0E7225B: { // 1428-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0uNx3bey_sendMessage);
      break;
    }
    case 0xE6486F5F: { // 1428-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_t02eVlBO_sendMessage);
      break;
    }
    case 0xF65E8330: { // 1507-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_F3Li0fNB_sendMessage);
      break;
    }
    case 0x3B8B5FB8: { // 1507-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TJD4nbWL_sendMessage);
      break;
    }
    case 0xE5F26E0D: { // 1507-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9HRPrj22_sendMessage);
      break;
    }
    case 0xFDAB8735: { // 1507-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9gNJyThY_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lfhBGKcU_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VHfEqECx_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DL3Y::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Cross";
        info->hash = 0xBB584857;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Sync";
        info->hash = 0xDD62B09F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "High_Time";
        info->hash = 0xABB0CBCF;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 6: {
        info->name = "High_TimeSync";
        info->hash = 0xAE942A2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 7: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low_Cross";
        info->hash = 0xA2D68920;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 9: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 10: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 11: {
        info->name = "Low_Sync";
        info->hash = 0xFFFEE96;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Time";
        info->hash = 0xA3BD8A20;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 13: {
        info->name = "Low_TimeSync";
        info->hash = 0x67F58CFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 14: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Cross";
        info->hash = 0x59607D3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 16: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Sync";
        info->hash = 0x96E19510;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Time";
        info->hash = 0xE1DB1774;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 21: {
        info->name = "Mid_TimeSync";
        info->hash = 0xDB67B94E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 22;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DL3Y::cVar_cxxQrLLv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ff38bxvL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_M1BElmmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I3Tp0uCl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_4CCMkPuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D2Xsl1p4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_M099If1F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FmJlTKL4_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M6F7XLD0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cuSCrpyN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3HeDJqgo_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_ShQMprn3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LyZgYwjs, 0, m, &cSlice_LyZgYwjs_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ZR2KDxbl_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_LyZgYwjs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NBNp7mVQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NBNp7mVQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_DCAGpsrt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NBNp7mVQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_NBNp7mVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xYyoMlcg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_mQZfrxjo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_O288Preb_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_lL1fHdyC, 0, m, &cIf_lL1fHdyC_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_lL1fHdyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_XvpRn9sC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_cZA12R40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_9YvKTAyp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_i6adKs9w_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_LmB1EGlI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_O6VJLiVF, HV_BINOP_POW, 0, m, &cBinop_O6VJLiVF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_O6VJLiVF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LyuB0eKp, 0, m, &cIf_LyuB0eKp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yYzXmcdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_dIqD8DzE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sTJsI2f5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_3ps3ctGT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vvFMHaaP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cZA12R40, 0, m, &cIf_cZA12R40_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3ps3ctGT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cZA12R40, 1, m, &cIf_cZA12R40_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_i6adKs9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_yYzXmcdq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9YvKTAyp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_LyuB0eKp, 0, m, &cIf_LyuB0eKp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dIqD8DzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O6VJLiVF, HV_BINOP_POW, 1, m, &cBinop_O6VJLiVF_sendMessage);
  cMsg_LmB1EGlI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_LyuB0eKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_jwVmV3J4, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_O288Preb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lL1fHdyC, 1, m, &cIf_lL1fHdyC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XvpRn9sC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A7RHhWvn, HV_BINOP_GREATER_THAN, 1, m, &cBinop_A7RHhWvn_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RSChAT3j, HV_BINOP_EQ, 1, m, &cBinop_RSChAT3j_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6N4B8wes_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ke0u078J, HV_BINOP_ADD, 0, m, &cBinop_Ke0u078J_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ke0u078J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sTJsI2f5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vvFMHaaP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_A7RHhWvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LyuB0eKp, 1, m, &cIf_LyuB0eKp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RSChAT3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e4tZoOia_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_e4tZoOia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_jwVmV3J4, m);
}

void Heavy_WSTD_DL3Y::cCast_KxErxoS9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ke0u078J, HV_BINOP_ADD, 1, m, &cBinop_Ke0u078J_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_A7RHhWvn, HV_BINOP_GREATER_THAN, 0, m, &cBinop_A7RHhWvn_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RSChAT3j, HV_BINOP_EQ, 0, m, &cBinop_RSChAT3j_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_FurvL8FG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6N4B8wes_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_u2P7FlRF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mQZfrxjo, 0, m, &cVar_mQZfrxjo_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_n6WLH7zP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_CmSdAH2o_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_iV0dq44k, 0, m, &cIf_iV0dq44k_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_iV0dq44k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_8d2cNdiZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_f2UBLz1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_SdP9h7cL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_rnzs8LC9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_ThGX6sSs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7vmtFT0a, HV_BINOP_POW, 0, m, &cBinop_7vmtFT0a_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7vmtFT0a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZGIXDThq, 0, m, &cIf_ZGIXDThq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_00GQi3Ch_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_vv6g6lR9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LZLIQ5fa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_jpmMYZpJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QGKIEKlt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_f2UBLz1U, 0, m, &cIf_f2UBLz1U_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jpmMYZpJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_f2UBLz1U, 1, m, &cIf_f2UBLz1U_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rnzs8LC9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_00GQi3Ch_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SdP9h7cL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ZGIXDThq, 0, m, &cIf_ZGIXDThq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vv6g6lR9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7vmtFT0a, HV_BINOP_POW, 1, m, &cBinop_7vmtFT0a_sendMessage);
  cMsg_ThGX6sSs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_ZGIXDThq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_K4wflYqE_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nIxBSV5b_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_M8Uwkk6w_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_CmSdAH2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iV0dq44k, 1, m, &cIf_iV0dq44k_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8d2cNdiZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lwl5NuNM, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Lwl5NuNM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pN4RM8Kn, HV_BINOP_EQ, 1, m, &cBinop_pN4RM8Kn_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XqICflGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AsRZZ4Ka, HV_BINOP_ADD, 0, m, &cBinop_AsRZZ4Ka_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AsRZZ4Ka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LZLIQ5fa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QGKIEKlt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Lwl5NuNM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZGIXDThq, 1, m, &cIf_ZGIXDThq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pN4RM8Kn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n8zAQLoX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_n8zAQLoX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_K4wflYqE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nIxBSV5b_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_M8Uwkk6w_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NRdocnMv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XqICflGN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_To0AhPEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AsRZZ4Ka, HV_BINOP_ADD, 1, m, &cBinop_AsRZZ4Ka_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lwl5NuNM, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Lwl5NuNM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pN4RM8Kn, HV_BINOP_EQ, 0, m, &cBinop_pN4RM8Kn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ayLqH03L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_n6WLH7zP, 0, m, &cVar_n6WLH7zP_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_XUYoBd2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_W6N47QQV_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_eMpVu2Ga, 0, m, &cIf_eMpVu2Ga_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_eMpVu2Ga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_jeXDz0PP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_4q8GxnWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_8WSBCald_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_IcRtnKmt_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_Ggldq5mD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oOQ1JgQL, HV_BINOP_POW, 0, m, &cBinop_oOQ1JgQL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oOQ1JgQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UNwDak3N, 0, m, &cIf_UNwDak3N_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8SJkGigY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_M4qNZ2oV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CJaRv44v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_3VnR9WVk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_s8U6vZXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4q8GxnWe, 0, m, &cIf_4q8GxnWe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3VnR9WVk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4q8GxnWe, 1, m, &cIf_4q8GxnWe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IcRtnKmt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_8SJkGigY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8WSBCald_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_UNwDak3N, 0, m, &cIf_UNwDak3N_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_M4qNZ2oV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oOQ1JgQL, HV_BINOP_POW, 1, m, &cBinop_oOQ1JgQL_sendMessage);
  cMsg_Ggldq5mD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_UNwDak3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_T4VZ0KYY, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_W6N47QQV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eMpVu2Ga, 1, m, &cIf_eMpVu2Ga_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jeXDz0PP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EXfduDmK, HV_BINOP_GREATER_THAN, 1, m, &cBinop_EXfduDmK_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3KDtpQLo, HV_BINOP_EQ, 1, m, &cBinop_3KDtpQLo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cdNKEk93_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_paaiBBkN, HV_BINOP_ADD, 0, m, &cBinop_paaiBBkN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_paaiBBkN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CJaRv44v_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s8U6vZXw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EXfduDmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UNwDak3N, 1, m, &cIf_UNwDak3N_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3KDtpQLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LpU8pV8Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_LpU8pV8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_T4VZ0KYY, m);
}

void Heavy_WSTD_DL3Y::cCast_Ircxo2Zv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_paaiBBkN, HV_BINOP_ADD, 1, m, &cBinop_paaiBBkN_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EXfduDmK, HV_BINOP_GREATER_THAN, 0, m, &cBinop_EXfduDmK_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3KDtpQLo, HV_BINOP_EQ, 0, m, &cBinop_3KDtpQLo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_t0u993e4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cdNKEk93_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_4D99cDom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XUYoBd2C, 0, m, &cVar_XUYoBd2C_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_7WCnghxb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_vrczjGTs, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_mk3kQezx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XZnYvNV6, 0, m, &cSlice_XZnYvNV6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_B3N3Gjzr_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_XZnYvNV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_grenU3e3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_grenU3e3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_SI82aWPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_grenU3e3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_grenU3e3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hbh2o6hq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_B3N3Gjzr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CKdRU5sG, 0, m, &cSlice_CKdRU5sG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ShQMprn3_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_CKdRU5sG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_BTGUrtM7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_BTGUrtM7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_GNuuymJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BTGUrtM7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_BTGUrtM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XP7CqH2d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_ZR2KDxbl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_FSGXAGDn, 0, m, &cSlice_FSGXAGDn_sendMessage);
      break;
    }
    default: {
      cSwitchcase_5cTuhpWr_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_FSGXAGDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_TaauaUu5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_TaauaUu5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_Z3k4yrjR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TaauaUu5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_TaauaUu5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CspsPfOP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_5cTuhpWr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xuVQVVS1, 0, m, &cSlice_xuVQVVS1_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_xuVQVVS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9QK39oXv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9QK39oXv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_DWSAn3xD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9QK39oXv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_9QK39oXv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LHmAyIjr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_8MGzhJil_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2oA7sfgm, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_o9mbx3Iz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TuY09ETd, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_QVuwU6A6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IhnTv8SQ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_6aEywdky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yE9H23On, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_l5uzt1yN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Q9FHUFOi, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_VqCS5uRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gfZB0OLv_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_gfZB0OLv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cPIbvZSo, HV_BINOP_DIVIDE, 1, m, &cBinop_cPIbvZSo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_blZX9Zf4_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_b1xuZ5IY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Uq98PGSM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hFCD16f7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_b1xuZ5IY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Uq98PGSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cPIbvZSo, HV_BINOP_DIVIDE, 0, m, &cBinop_cPIbvZSo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_blZX9Zf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hFCD16f7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_cPIbvZSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FooeIsxx, HV_BINOP_MULTIPLY, 1, m, &cBinop_FooeIsxx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FooeIsxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oy56jpXl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Y6EWGhcv_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_bGnYtOU4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BQIuCCcZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_uIRdHQlA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BtKUIbmV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_D3PWk3ej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_V9SbWZl5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_V9SbWZl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FooeIsxx, HV_BINOP_MULTIPLY, 0, m, &cBinop_FooeIsxx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ST54CJhb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_KU8coqsL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KU8coqsL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PEFc6Aml_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_QUAy1bdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4KOoNUSH, 1, m, &cVar_4KOoNUSH_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_4KOoNUSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oOXI1wUd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_kdTN56XK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dHaRxvNO, HV_BINOP_MULTIPLY, 1, m, &cBinop_dHaRxvNO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dosVlFdl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_kdTN56XK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_S6arLEky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_BRFET1df_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BRFET1df_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_USdkIcII, HV_BINOP_MULTIPLY, 1, m, &cBinop_USdkIcII_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PsnlHzS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4eiPbojW, HV_BINOP_MULTIPLY, 1, m, &cBinop_4eiPbojW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gYmf1KHt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_PsnlHzS1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aoTOluNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tiyGTEOR, HV_BINOP_MULTIPLY, 1, m, &cBinop_tiyGTEOR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UBNRkf7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_1AE3Mm1F_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1AE3Mm1F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rzVyBGxR, HV_BINOP_MULTIPLY, 1, m, &cBinop_rzVyBGxR_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_8RY5oQ5q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_l9kTiwOC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_D3PWk3ej_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PEO9HTnx_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_rHKqaPy8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_ST54CJhb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Y6EWGhcv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_uIRdHQlA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_oy56jpXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_bGnYtOU4_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_BQIuCCcZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Nf01sc3Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_BtKUIbmV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MeacDDta_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_s30303Fx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_moFlU1mO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_PEFc6Aml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_41X1kmSl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_41X1kmSl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LmoUtc4k, HV_BINOP_MULTIPLY, 1, m, &cBinop_LmoUtc4k_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LmoUtc4k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_FXbRUMUF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FXbRUMUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_s30303Fx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_oOXI1wUd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qRdfom4J_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qRdfom4J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MbMotAQC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ky0y5lo6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zDlgFoTq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_618dmMxi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qrhDcZEM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lWqrSVMk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dHaRxvNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8MGzhJil_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_USdkIcII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o9mbx3Iz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_4eiPbojW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QVuwU6A6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_tiyGTEOR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6aEywdky_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_rzVyBGxR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l5uzt1yN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_XsI4Zl2p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8RY5oQ5q, 0, m, &cVar_8RY5oQ5q_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hoh9lRm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rHKqaPy8, 1, m, &cVar_rHKqaPy8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_618dmMxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4eiPbojW, HV_BINOP_MULTIPLY, 0, m, &cBinop_4eiPbojW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_MbMotAQC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_zDlgFoTq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tiyGTEOR, HV_BINOP_MULTIPLY, 0, m, &cBinop_tiyGTEOR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qrhDcZEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_USdkIcII, HV_BINOP_MULTIPLY, 0, m, &cBinop_USdkIcII_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ky0y5lo6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rzVyBGxR, HV_BINOP_MULTIPLY, 0, m, &cBinop_rzVyBGxR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lWqrSVMk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dHaRxvNO, HV_BINOP_MULTIPLY, 0, m, &cBinop_dHaRxvNO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_l9kTiwOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rHKqaPy8, 0, m, &cVar_rHKqaPy8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_PEO9HTnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4KOoNUSH, 0, m, &cVar_4KOoNUSH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gDCjgpMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NCEp5pmf, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_8t3KHwCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ep6UuHZl, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_5hGZd7or_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pI6D5OD0, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_PtIy5f3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rMu40C5n, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Jvj7e1fe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_S67qlaj6_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_S67qlaj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qPlAavvp, HV_BINOP_DIVIDE, 1, m, &cBinop_qPlAavvp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cdQTuWso_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_IqiZQ9qK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_31AXZ95o_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OVCUHZK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_IqiZQ9qK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_31AXZ95o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qPlAavvp, HV_BINOP_DIVIDE, 0, m, &cBinop_qPlAavvp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cdQTuWso_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OVCUHZK4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_qPlAavvp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NIAXR70u, HV_BINOP_MULTIPLY, 1, m, &cBinop_NIAXR70u_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NIAXR70u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QFG58lAw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lyd1gwdQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_MHcCEm8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2m6VJWfV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_qN3mjR5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iU1w68NQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_makeE0kP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_dJLrjl2K_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dJLrjl2K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NIAXR70u, HV_BINOP_MULTIPLY, 0, m, &cBinop_NIAXR70u_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nRDr2YWR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_LtlHO6JI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LtlHO6JI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8zrclTnN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vIo7jR81_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YUlFJ4eu, HV_BINOP_MULTIPLY, 1, m, &cBinop_YUlFJ4eu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JPRFS4XN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_n98WZNDD, 1, m, &cVar_n98WZNDD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Tbyyc5Jh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_532v9AMv, HV_BINOP_MULTIPLY, 1, m, &cBinop_532v9AMv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wD4QZody_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_EWIiyUYb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EWIiyUYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jeGJ546x, HV_BINOP_MULTIPLY, 1, m, &cBinop_jeGJ546x_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_n98WZNDD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3aTzHAjK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_6fse0yqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8oqu1z4X_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_makeE0kP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Pdf4HIPe_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_rPLqoEcb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_nRDr2YWR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QFG58lAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_MHcCEm8d_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lyd1gwdQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_qN3mjR5g_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_2m6VJWfV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DY7VUTfA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_iU1w68NQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wQjsqamu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_9UqIA55f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Jrgh0QzV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_8zrclTnN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Kho0JJ5G_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Kho0JJ5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JfndkYEu, HV_BINOP_MULTIPLY, 1, m, &cBinop_JfndkYEu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JfndkYEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_NmHKxRO2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NmHKxRO2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9UqIA55f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_3aTzHAjK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Q2l0T7HL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Q2l0T7HL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GIv1m8VY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Bv0HnGJM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q0heF6HJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VCsskHq5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_51ekKGyS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gDCjgpMj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_YUlFJ4eu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8t3KHwCs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_532v9AMv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5hGZd7or_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_jeGJ546x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PtIy5f3r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_73rNq49A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6fse0yqs, 0, m, &cVar_6fse0yqs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vfHJPO9m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rPLqoEcb, 1, m, &cVar_rPLqoEcb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Pdf4HIPe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_n98WZNDD, 0, m, &cVar_n98WZNDD_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8oqu1z4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rPLqoEcb, 0, m, &cVar_rPLqoEcb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VCsskHq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_51ekKGyS, HV_BINOP_MULTIPLY, 0, m, &cBinop_51ekKGyS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Q0heF6HJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YUlFJ4eu, HV_BINOP_MULTIPLY, 0, m, &cBinop_YUlFJ4eu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Bv0HnGJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_532v9AMv, HV_BINOP_MULTIPLY, 0, m, &cBinop_532v9AMv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_GIv1m8VY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jeGJ546x, HV_BINOP_MULTIPLY, 0, m, &cBinop_jeGJ546x_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gqY0Nihp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_593uHNv0, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_xNnKPCIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_twYcT8JJ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_nwv6Os3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_38198bpS, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_660pqc29_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0Nt6SWVX, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_0A8Lrxwo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b3c8LHzh, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_dDjmhAEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_y1PavAtK_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_y1PavAtK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iwAMzmYW, HV_BINOP_DIVIDE, 1, m, &cBinop_iwAMzmYW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V4fpWpDi_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_PAvfwjkk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_6nlJVP8V_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_F0PYPRYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_PAvfwjkk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6nlJVP8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iwAMzmYW, HV_BINOP_DIVIDE, 0, m, &cBinop_iwAMzmYW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_V4fpWpDi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F0PYPRYV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_iwAMzmYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VENQ3jPZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_VENQ3jPZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VENQ3jPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_13NPIgwt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZyoqoRGD_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_kLyOYGOn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NojYe1ob_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_fP8xXYKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sM80gSDH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_wnCTucM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_3rywCUFF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3rywCUFF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VENQ3jPZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_VENQ3jPZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6NEa7sg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_zJ0c0oJr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zJ0c0oJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f7HShIQU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_8PNFRmqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1oDyPN7x, HV_BINOP_MULTIPLY, 1, m, &cBinop_1oDyPN7x_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ofhWDUwo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_d0XPUfUX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_d0XPUfUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_8PNFRmqr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9uacLuiz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_KMVvv7ZR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KMVvv7ZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gsNBelOe, HV_BINOP_MULTIPLY, 1, m, &cBinop_gsNBelOe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YN7vJ1Zs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bLUthpNQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_bLUthpNQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HZjYQ9BO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_cHrQe9kG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cHrQe9kG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_YN7vJ1Zs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4CIWX4bz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wRMa5j8D, 1, m, &cVar_wRMa5j8D_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6k7ddLKz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CEgnlP8u, HV_BINOP_MULTIPLY, 1, m, &cBinop_CEgnlP8u_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_28d9FChS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_qABtnzjW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qABtnzjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7GSVYeUz, HV_BINOP_MULTIPLY, 1, m, &cBinop_7GSVYeUz_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_wRMa5j8D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JFTG3x4e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_m2MMB7lY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wGNf0vzs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_wnCTucM8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h4vJuGro_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_UJg40Vzs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_6NEa7sg3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZyoqoRGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_fP8xXYKl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_13NPIgwt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_kLyOYGOn_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_NojYe1ob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qqaNsAcw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_sM80gSDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Tb36u82i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_fxaaYKRq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_i3yNzgeI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_f7HShIQU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_eJuLOBEC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eJuLOBEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BxrOejqu, HV_BINOP_MULTIPLY, 1, m, &cBinop_BxrOejqu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BxrOejqu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ZFlwrFpz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZFlwrFpz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fxaaYKRq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_JFTG3x4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_vu3rCgRh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vu3rCgRh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L3rClucM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LiXjfchP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_J0BjMBgE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HtdBST7k_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1e2TlkGw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Xx23kzgr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1oDyPN7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gqY0Nihp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_gsNBelOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xNnKPCIp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bLUthpNQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nwv6Os3f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_CEgnlP8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_660pqc29_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_7GSVYeUz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0A8Lrxwo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_kvleuYyj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_m2MMB7lY, 0, m, &cVar_m2MMB7lY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_uvpvSqUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UJg40Vzs, 1, m, &cVar_UJg40Vzs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_HtdBST7k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bLUthpNQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_bLUthpNQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LiXjfchP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7GSVYeUz, HV_BINOP_MULTIPLY, 0, m, &cBinop_7GSVYeUz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Xx23kzgr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1oDyPN7x, HV_BINOP_MULTIPLY, 0, m, &cBinop_1oDyPN7x_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1e2TlkGw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gsNBelOe, HV_BINOP_MULTIPLY, 0, m, &cBinop_gsNBelOe_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_L3rClucM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_J0BjMBgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CEgnlP8u, HV_BINOP_MULTIPLY, 0, m, &cBinop_CEgnlP8u_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_h4vJuGro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wRMa5j8D, 0, m, &cVar_wRMa5j8D_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wGNf0vzs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UJg40Vzs, 0, m, &cVar_UJg40Vzs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_K4wflYqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7WCnghxb, 1, m, &cIf_7WCnghxb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oy5dhzLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_vrczjGTs, m);
}

void Heavy_WSTD_DL3Y::cBinop_nIxBSV5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oy5dhzLS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_M8Uwkk6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7WCnghxb, 0, m, &cIf_7WCnghxb_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_hwPQg1S9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_wMzOzRuV, 0, m, &cSlice_wMzOzRuV_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Bp1gdqjI_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_wMzOzRuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_uH7bUp5b_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_uH7bUp5b_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_6RiZ01OC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uH7bUp5b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_uH7bUp5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QYwrIzxp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_mXCCbJU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_pv6hTJJw_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_NRaa6QmT, 0, m, &cIf_NRaa6QmT_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_NRaa6QmT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_H4B3o6mg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_qBaOlj99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_86RBsrjH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_uRb4x7IX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_4tmdz5RY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gq3zWd7R, HV_BINOP_POW, 0, m, &cBinop_gq3zWd7R_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gq3zWd7R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZoptMGH3, 0, m, &cIf_ZoptMGH3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3pVakrXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_6yQnj5R8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5XpXjuuB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qBaOlj99, 0, m, &cIf_qBaOlj99_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_mzUnxPAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_g4nPJAFn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_g4nPJAFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qBaOlj99, 1, m, &cIf_qBaOlj99_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uRb4x7IX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_3pVakrXP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_86RBsrjH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ZoptMGH3, 0, m, &cIf_ZoptMGH3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6yQnj5R8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gq3zWd7R, HV_BINOP_POW, 1, m, &cBinop_gq3zWd7R_sendMessage);
  cMsg_4tmdz5RY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_ZoptMGH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_jDCQyZo4, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_pv6hTJJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NRaa6QmT, 1, m, &cIf_NRaa6QmT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_H4B3o6mg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PkAaE755, HV_BINOP_GREATER_THAN, 1, m, &cBinop_PkAaE755_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6zP3N03w, HV_BINOP_EQ, 1, m, &cBinop_6zP3N03w_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_F66MnOaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7dcKq2fK, HV_BINOP_ADD, 0, m, &cBinop_7dcKq2fK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7dcKq2fK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mzUnxPAS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5XpXjuuB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PkAaE755_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZoptMGH3, 1, m, &cIf_ZoptMGH3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6zP3N03w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SfUKhblA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_SfUKhblA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_jDCQyZo4, m);
}

void Heavy_WSTD_DL3Y::cCast_pI7UG4ZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F66MnOaj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_3bJiWD0M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7dcKq2fK, HV_BINOP_ADD, 1, m, &cBinop_7dcKq2fK_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PkAaE755, HV_BINOP_GREATER_THAN, 0, m, &cBinop_PkAaE755_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6zP3N03w, HV_BINOP_EQ, 0, m, &cBinop_6zP3N03w_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_f0LImA3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mXCCbJU8, 0, m, &cVar_mXCCbJU8_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_ds3Y0ZbT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_sw8LyhCq_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_dwkA167N, 0, m, &cIf_dwkA167N_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_dwkA167N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4qxaZmeb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_bSH1jJnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_7pmJRWV0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_t7mO9IuT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_n8CUZg78_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_kqzZ9Dhe, HV_BINOP_POW, 0, m, &cBinop_kqzZ9Dhe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kqzZ9Dhe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7RFJm1ji, 0, m, &cIf_7RFJm1ji_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lWtnAO2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_T2jhRYPj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4bsLfpso_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bSH1jJnF, 0, m, &cIf_bSH1jJnF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_efPJEdFR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ikleR9ob_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ikleR9ob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bSH1jJnF, 1, m, &cIf_bSH1jJnF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_t7mO9IuT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_lWtnAO2g_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7pmJRWV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_7RFJm1ji, 0, m, &cIf_7RFJm1ji_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_T2jhRYPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kqzZ9Dhe, HV_BINOP_POW, 1, m, &cBinop_kqzZ9Dhe_sendMessage);
  cMsg_n8CUZg78_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_7RFJm1ji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_kZ031Fhy_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uvcgdjyP_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_2Dz8meD2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_sw8LyhCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dwkA167N, 1, m, &cIf_dwkA167N_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4qxaZmeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1qVFACP1, HV_BINOP_GREATER_THAN, 1, m, &cBinop_1qVFACP1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Uxv1lE2r, HV_BINOP_EQ, 1, m, &cBinop_Uxv1lE2r_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZCOGhUad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1fcRT3cL, HV_BINOP_ADD, 0, m, &cBinop_1fcRT3cL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1fcRT3cL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_efPJEdFR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4bsLfpso_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1qVFACP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7RFJm1ji, 1, m, &cIf_7RFJm1ji_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Uxv1lE2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eI1PX4R7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_eI1PX4R7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_kZ031Fhy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uvcgdjyP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_2Dz8meD2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DWOTawss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZCOGhUad_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_PUzTOcdv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1fcRT3cL, HV_BINOP_ADD, 1, m, &cBinop_1fcRT3cL_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1qVFACP1, HV_BINOP_GREATER_THAN, 0, m, &cBinop_1qVFACP1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Uxv1lE2r, HV_BINOP_EQ, 0, m, &cBinop_Uxv1lE2r_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XnihG6tC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ds3Y0ZbT, 0, m, &cVar_ds3Y0ZbT_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_eEkNIBET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wrugPv0l_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_QFefm8yF, 0, m, &cIf_QFefm8yF_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_QFefm8yF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_2tna0FUj_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_LJLJDizT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_RXy0Oa4s_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_vNztl5sq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_Wy4RWOLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_nogIiuYI, HV_BINOP_POW, 0, m, &cBinop_nogIiuYI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nogIiuYI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CThr5J1N, 0, m, &cIf_CThr5J1N_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vFhFAuTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_B9sy2hO2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wes56LSN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LJLJDizT, 0, m, &cIf_LJLJDizT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_2UBazqSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Nn6yl3x1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Nn6yl3x1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LJLJDizT, 1, m, &cIf_LJLJDizT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vNztl5sq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_vFhFAuTn_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RXy0Oa4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_CThr5J1N, 0, m, &cIf_CThr5J1N_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_B9sy2hO2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nogIiuYI, HV_BINOP_POW, 1, m, &cBinop_nogIiuYI_sendMessage);
  cMsg_Wy4RWOLl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_CThr5J1N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Zi9H2KQy, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_wrugPv0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QFefm8yF, 1, m, &cIf_QFefm8yF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2tna0FUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qb4vMCS7, HV_BINOP_GREATER_THAN, 1, m, &cBinop_qb4vMCS7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9WQ63N2J, HV_BINOP_EQ, 1, m, &cBinop_9WQ63N2J_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4vhk65sO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qVLWz643, HV_BINOP_ADD, 0, m, &cBinop_qVLWz643_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qVLWz643_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2UBazqSM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wes56LSN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qb4vMCS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CThr5J1N, 1, m, &cIf_CThr5J1N_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9WQ63N2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sMTTxVpd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_sMTTxVpd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Zi9H2KQy, m);
}

void Heavy_WSTD_DL3Y::cCast_zx9VVAmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eEkNIBET, 0, m, &cVar_eEkNIBET_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Rgmsmtcu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4vhk65sO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_2AqRguPk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qVLWz643, HV_BINOP_ADD, 1, m, &cBinop_qVLWz643_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qb4vMCS7, HV_BINOP_GREATER_THAN, 0, m, &cBinop_qb4vMCS7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9WQ63N2J, HV_BINOP_EQ, 0, m, &cBinop_9WQ63N2J_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_34M4KyqF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_V4kp1T7G, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_hwKEEpCW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_eeavX0dz, 0, m, &cSlice_eeavX0dz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_3Ce1gcEy_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_eeavX0dz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_lBVaZ5KZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_lBVaZ5KZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_pfN4GjrM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lBVaZ5KZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_lBVaZ5KZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1iChQWl5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_3Ce1gcEy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ze9Dm9Fr, 0, m, &cSlice_ze9Dm9Fr_sendMessage);
      break;
    }
    default: {
      cSwitchcase_hwPQg1S9_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_ze9Dm9Fr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_QOrgYCWv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_QOrgYCWv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_ittQyS7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QOrgYCWv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_QOrgYCWv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tQHMpFjK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Bp1gdqjI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_kUkHa0E6, 0, m, &cSlice_kUkHa0E6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_3ZofKT0T_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_kUkHa0E6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_QDoZpG6U_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_QDoZpG6U_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_P9pvGXEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QDoZpG6U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_QDoZpG6U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NinU2bsY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_3ZofKT0T_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_KLnEO0Nh, 0, m, &cSlice_KLnEO0Nh_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_KLnEO0Nh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ceXeZt6c_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ceXeZt6c_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_WArCMriK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ceXeZt6c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_ceXeZt6c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_anGDLL73_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_O9iedzYI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_E2Gpf6sL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_d0qH19Q0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HiuaC8y2, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_zvalOl62_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bvFDyvHj, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_RY2C0Crk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0MKEaSrz, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_cj0u2ehX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dTwWljtH, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Z6EDQVRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QnOT9Ve7_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_QnOT9Ve7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PhHIlBSm, HV_BINOP_DIVIDE, 1, m, &cBinop_PhHIlBSm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TBTEH4Au_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_8nDGTQXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_bWGPwE55_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gxbKIVLN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_8nDGTQXX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bWGPwE55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PhHIlBSm, HV_BINOP_DIVIDE, 0, m, &cBinop_PhHIlBSm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TBTEH4Au_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gxbKIVLN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_PhHIlBSm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5QO47nES, HV_BINOP_MULTIPLY, 1, m, &cBinop_5QO47nES_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5QO47nES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sN0KVeZ4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4y75FHlP_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_VaSGZdIl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_URD9B34G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_wmOJZdw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_a3KjJKpt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_NWzkPFTr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_0H7pCBaX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0H7pCBaX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5QO47nES, HV_BINOP_MULTIPLY, 0, m, &cBinop_5QO47nES_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4Th1uPVF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_3UxcZAZP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3UxcZAZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F3J0Fou8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Mb4TD4Jv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GdlDbBkg, 1, m, &cVar_GdlDbBkg_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_GdlDbBkg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xEpzesYR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_63PCyOIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xUMeshZl, HV_BINOP_MULTIPLY, 1, m, &cBinop_xUMeshZl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CMGFRSFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_63PCyOIy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZqfzCj9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_YH8gNAP5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YH8gNAP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rsCrb6Re, HV_BINOP_MULTIPLY, 1, m, &cBinop_rsCrb6Re_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9Np4EPFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JvULyDzm, HV_BINOP_MULTIPLY, 1, m, &cBinop_JvULyDzm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GsnLs2Vp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9Np4EPFi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Z7YEHmGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NVcHqk2H, HV_BINOP_MULTIPLY, 1, m, &cBinop_NVcHqk2H_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XVnM42Ry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_S4cC6l0w_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_S4cC6l0w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VS70miQL, HV_BINOP_MULTIPLY, 1, m, &cBinop_VS70miQL_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_dbniPqPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8ltWgG92_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_NWzkPFTr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Db6ZRG6h_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_LoTZQOlp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_4Th1uPVF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sN0KVeZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_VaSGZdIl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4y75FHlP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_wmOJZdw6_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_URD9B34G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5NBDj3wk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_a3KjJKpt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SWBJm4AX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_ZfKJ14rm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sj19YkBv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_F3J0Fou8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_KQDxdQLb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KQDxdQLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p0MimApN, HV_BINOP_MULTIPLY, 1, m, &cBinop_p0MimApN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_p0MimApN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_eCIamgEE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eCIamgEE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZfKJ14rm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_xEpzesYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_bvTFzpLZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bvTFzpLZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uJgoxg3M_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hoY6UeOz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EVoa8KDc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HgICXYuj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lno1m4ql_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ljhfY0RI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xUMeshZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O9iedzYI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_rsCrb6Re_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d0qH19Q0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_JvULyDzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zvalOl62_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_NVcHqk2H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RY2C0Crk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_VS70miQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cj0u2ehX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_rL5GWGEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LoTZQOlp, 1, m, &cVar_LoTZQOlp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hdyNufV3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dbniPqPi, 0, m, &cVar_dbniPqPi_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ljhfY0RI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xUMeshZl, HV_BINOP_MULTIPLY, 0, m, &cBinop_xUMeshZl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_HgICXYuj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JvULyDzm, HV_BINOP_MULTIPLY, 0, m, &cBinop_JvULyDzm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EVoa8KDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NVcHqk2H, HV_BINOP_MULTIPLY, 0, m, &cBinop_NVcHqk2H_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hoY6UeOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VS70miQL, HV_BINOP_MULTIPLY, 0, m, &cBinop_VS70miQL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lno1m4ql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rsCrb6Re, HV_BINOP_MULTIPLY, 0, m, &cBinop_rsCrb6Re_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_uJgoxg3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_Db6ZRG6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GdlDbBkg, 0, m, &cVar_GdlDbBkg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8ltWgG92_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LoTZQOlp, 0, m, &cVar_LoTZQOlp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MX0xy4CT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M6v7dLaC, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_qkfUpwH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3q34eYtg, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Zw45aQBy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NVKNfUn9, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ACmqlo8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qOgan6NH, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_rElxTpIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_u82qTHBb_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_u82qTHBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OGRdbRlk, HV_BINOP_DIVIDE, 1, m, &cBinop_OGRdbRlk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jT3uwuJE_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_FX5AbgSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_ZRRmYQvo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nymB40OO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_FX5AbgSg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZRRmYQvo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OGRdbRlk, HV_BINOP_DIVIDE, 0, m, &cBinop_OGRdbRlk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jT3uwuJE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nymB40OO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_OGRdbRlk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_haehmiWM, HV_BINOP_MULTIPLY, 1, m, &cBinop_haehmiWM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_haehmiWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gRJ0aZLe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ImTR2lPy_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_smcE3uo6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_K9dLPJ5o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_lD1r7hho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_73x5HU8D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_XzW6ZEj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_3Uz66YpQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3Uz66YpQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_haehmiWM, HV_BINOP_MULTIPLY, 0, m, &cBinop_haehmiWM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gdnWONnR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_ilO5tD4q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ilO5tD4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vPdPY4xM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vwrROOoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2I4vuqhv, HV_BINOP_MULTIPLY, 1, m, &cBinop_2I4vuqhv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kphcoe6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2UbxGgbJ, 1, m, &cVar_2UbxGgbJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_l5sW4Sa7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zf2eb50X, HV_BINOP_MULTIPLY, 1, m, &cBinop_Zf2eb50X_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mLvehn2K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_SzgqfMiw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SzgqfMiw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z5xDvD5e, HV_BINOP_MULTIPLY, 1, m, &cBinop_Z5xDvD5e_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_2UbxGgbJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_t5hjhsLx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_OcT4AKvb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GKReEFre_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_XzW6ZEj3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ynczkglv_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_HRfw6K6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_gdnWONnR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ImTR2lPy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_lD1r7hho_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gRJ0aZLe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_smcE3uo6_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_K9dLPJ5o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VLnWl3lw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_73x5HU8D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_K0R5fp0h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_80RGz395_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Q5yKSL6P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_vPdPY4xM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_TVt9GXPV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TVt9GXPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UaNq6Kvq, HV_BINOP_MULTIPLY, 1, m, &cBinop_UaNq6Kvq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UaNq6Kvq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qAN4cFqs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qAN4cFqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_80RGz395_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_t5hjhsLx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_5w1MiZjt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5w1MiZjt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EYudDxiT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ruo7nhCq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6CCEPxOu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4ZWLBE1C_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xkW1VZvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MX0xy4CT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_2I4vuqhv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qkfUpwH7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Zf2eb50X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Zw45aQBy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Z5xDvD5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ACmqlo8S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_fNJ9Wr56_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HRfw6K6g, 1, m, &cVar_HRfw6K6g_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_mL20tTNX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OcT4AKvb, 0, m, &cVar_OcT4AKvb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Ynczkglv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2UbxGgbJ, 0, m, &cVar_2UbxGgbJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_GKReEFre_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HRfw6K6g, 0, m, &cVar_HRfw6K6g_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4ZWLBE1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xkW1VZvY, HV_BINOP_MULTIPLY, 0, m, &cBinop_xkW1VZvY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6CCEPxOu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2I4vuqhv, HV_BINOP_MULTIPLY, 0, m, &cBinop_2I4vuqhv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ruo7nhCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zf2eb50X, HV_BINOP_MULTIPLY, 0, m, &cBinop_Zf2eb50X_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EYudDxiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z5xDvD5e, HV_BINOP_MULTIPLY, 0, m, &cBinop_Z5xDvD5e_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nFjvS6D1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WkngJ3XO, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_0J4xJ33u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xZqgTfuT, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_2HTmNibk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1FHfXI1L, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_4JnDEuvz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NBRfdjRL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ytViiC0V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JSqxpaNw, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_08Cnv8Z3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7Zl3HrTt_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_7Zl3HrTt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z6ibeN3d, HV_BINOP_DIVIDE, 1, m, &cBinop_Z6ibeN3d_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6UJGPjRa_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_m8daZKxu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_rre8LH1C_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YIph44nH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_m8daZKxu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rre8LH1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z6ibeN3d, HV_BINOP_DIVIDE, 0, m, &cBinop_Z6ibeN3d_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6UJGPjRa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YIph44nH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Z6ibeN3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kcYgMfwV, HV_BINOP_MULTIPLY, 1, m, &cBinop_kcYgMfwV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kcYgMfwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_h3qKRR28_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s32Fg74C_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_RBwOmKfl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_urZgUJFP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_ReYO8G8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4RWVzKfH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_OHhlrXRa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_dPAbyxmY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dPAbyxmY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kcYgMfwV, HV_BINOP_MULTIPLY, 0, m, &cBinop_kcYgMfwV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6Kg8vhkg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_agRV5H52_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_agRV5H52_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_668LaBlT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_NSmcFl9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hduPcjXo, HV_BINOP_MULTIPLY, 1, m, &cBinop_hduPcjXo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_m4A2LWcO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_zhVl9qKm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zhVl9qKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_NSmcFl9O_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lpgZw9EZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_xRGEdc6I_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xRGEdc6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FAduSLdn, HV_BINOP_MULTIPLY, 1, m, &cBinop_FAduSLdn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6qIYr3ti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6kr0ULS3, HV_BINOP_MULTIPLY, 1, m, &cBinop_6kr0ULS3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hXthcvxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_cIHgkJzl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cIHgkJzl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6qIYr3ti_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NtI6Y4kQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_atW42VWY, 1, m, &cVar_atW42VWY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dsoUQWyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zY7Is4WI, HV_BINOP_MULTIPLY, 1, m, &cBinop_zY7Is4WI_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MJI9XsWH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Hx92Puaq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Hx92Puaq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0T2boKRP, HV_BINOP_MULTIPLY, 1, m, &cBinop_0T2boKRP_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_atW42VWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wxI02yJw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_aWiIfSwa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yNmKN9gX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_OHhlrXRa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_un0oGVWk_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_OP2sDIRG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_6Kg8vhkg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_h3qKRR28_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_RBwOmKfl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_s32Fg74C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_ReYO8G8z_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_urZgUJFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tFWWhnEU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_4RWVzKfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_oVtv3ZMi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_9Rhu7QCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5whLPSVi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_668LaBlT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_9xU7tSxO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9xU7tSxO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dVlqQS01, HV_BINOP_MULTIPLY, 1, m, &cBinop_dVlqQS01_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dVlqQS01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ZHbIHnLB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZHbIHnLB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9Rhu7QCY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_wxI02yJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_eK1ypZR4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eK1ypZR4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z2OeFopL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FKJXxm1o_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_j1TWvlxa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0BgZF0qv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TjiszsSc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_INiBxleO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hduPcjXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nFjvS6D1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_FAduSLdn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0J4xJ33u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_6kr0ULS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2HTmNibk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_zY7Is4WI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4JnDEuvz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_0T2boKRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ytViiC0V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_kkqVOtoi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OP2sDIRG, 1, m, &cVar_OP2sDIRG_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_PhaGazaV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aWiIfSwa, 0, m, &cVar_aWiIfSwa_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0BgZF0qv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6kr0ULS3, HV_BINOP_MULTIPLY, 0, m, &cBinop_6kr0ULS3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_FKJXxm1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0T2boKRP, HV_BINOP_MULTIPLY, 0, m, &cBinop_0T2boKRP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_INiBxleO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hduPcjXo, HV_BINOP_MULTIPLY, 0, m, &cBinop_hduPcjXo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TjiszsSc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FAduSLdn, HV_BINOP_MULTIPLY, 0, m, &cBinop_FAduSLdn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_z2OeFopL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_j1TWvlxa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zY7Is4WI, HV_BINOP_MULTIPLY, 0, m, &cBinop_zY7Is4WI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yNmKN9gX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OP2sDIRG, 0, m, &cVar_OP2sDIRG_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_un0oGVWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_atW42VWY, 0, m, &cVar_atW42VWY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kZ031Fhy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_34M4KyqF, 1, m, &cIf_34M4KyqF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IiEiSmxD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_V4kp1T7G, m);
}

void Heavy_WSTD_DL3Y::cBinop_uvcgdjyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IiEiSmxD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_2Dz8meD2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_34M4KyqF, 0, m, &cIf_34M4KyqF_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_xnzvPWWJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BdH9ivmz, HV_BINOP_DIVIDE, 0, m, &cBinop_BdH9ivmz_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_R4iBnpQY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U5Yl6zU5, HV_BINOP_DIVIDE, 1, m, &cBinop_U5Yl6zU5_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_BdH9ivmz, HV_BINOP_DIVIDE, 1, m, &cBinop_BdH9ivmz_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_ME5xiqw2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qHMSS57v, HV_BINOP_DIVIDE, 0, m, &cBinop_qHMSS57v_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_pvEZqZ1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qHMSS57v, HV_BINOP_DIVIDE, 1, m, &cBinop_qHMSS57v_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3HeDJqgo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U5Yl6zU5, HV_BINOP_DIVIDE, 0, m, &cBinop_U5Yl6zU5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cuSCrpyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xnzvPWWJ, 0, m, &cVar_xnzvPWWJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_M6F7XLD0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_R4iBnpQY, 0, m, &cVar_R4iBnpQY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_U5Yl6zU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_ME5xiqw2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BdH9ivmz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_pvEZqZ1y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qHMSS57v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_1zkgaWtK_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_Fg5Yq9e6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_pfEvdkTk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hl0MHzaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_T2nqlbgd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1zkgaWtK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_hl0MHzaZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_T2nqlbgd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_Fg5Yq9e6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pfEvdkTk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mIaADiiQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_T5QgclAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CCKeGqRM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_0ddi3Qld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f4sA6HuQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_0VWzsqzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Al8aaqFV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_94kfXfc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GuUsYa7O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_e6Fatjfe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AxFl2K4l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_n6r9BSz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rAvlWWrd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_lbSAm9zV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l9J1bni0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_hMkDTYQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ah0jR9a1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_hGaBYCEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TE7Lfnya_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_wcXCsTCN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Todhl8wM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_W4DERNiU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P4uQsMS5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_lLrbhtQi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Iw7Uf7VS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_erqAJVpv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_TTSKtLhm, 0, m, &cSlice_TTSKtLhm_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_TTSKtLhm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_PQXGgGJ1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_PQXGgGJ1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_mETmPcNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PQXGgGJ1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_PQXGgGJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZvnMWcNk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_vd6AaAe1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7zTFFsW4, 0, m, &cSlice_7zTFFsW4_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Q2t2mJdc_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_7zTFFsW4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EMNhZ5mm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EMNhZ5mm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_xkyb6vYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EMNhZ5mm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_EMNhZ5mm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xkF4puXG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_yiAzU76f_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9sw92gbO, 0, m, &cSlice_9sw92gbO_sendMessage);
      break;
    }
    default: {
      cSwitchcase_erqAJVpv_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_9sw92gbO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JIE2STJS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JIE2STJS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_GHhzdfso_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JIE2STJS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_JIE2STJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XomccZhE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_zrbkqJqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_XAwiPytN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XAwiPytN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_orJ2qFhp_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_YoH77LQk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S9ngTDZd_sendMessage(_c, 0, m);
  cMsg_5yL8Bp2p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_U7Ibckge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_92URsiib_sendMessage(_c, 0, m);
  cMsg_mxcEgy7I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_orJ2qFhp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_atxffO4q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_atxffO4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XWr4fvCw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IGc4DgDP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_IGc4DgDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QkJSF9sq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_XWr4fvCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_rmDVXAD5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rmDVXAD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_BAL9TQ2c_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QkJSF9sq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_v0v7es8P_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_v0v7es8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_HmCuLFuq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BAL9TQ2c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_YoH77LQk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HmCuLFuq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_U7Ibckge_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_c5wDnJmP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ZKbvfsDc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZKbvfsDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_Simo8vLY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Simo8vLY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_COxF0D5y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_COxF0D5y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4Ycd2DQv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pXfm5TRE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pXfm5TRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bLBXVxMr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_4Ycd2DQv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_GaZVoP1n_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GaZVoP1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ZeBKpd2m_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bLBXVxMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Hh65OUob_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Hh65OUob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_YO8OODae_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YO8OODae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HwiTBmyx_sendMessage(_c, 0, m);
  cMsg_YFOnXzmx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ZeBKpd2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Kz8ce5rc_sendMessage(_c, 0, m);
  cMsg_4WjihsRh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_mV4SUFdb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ftFgcsWz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ftFgcsWz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_eIejgKmi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_omnVYcRW_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_T8mSP6iT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_rJoihgtH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3drEDnsv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nFWG5ttP_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_nFWG5ttP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ae3TMMZt, HV_BINOP_DIVIDE, 1, m, &cBinop_ae3TMMZt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eIejgKmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_tCCnJ7vj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tCCnJ7vj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_HM6GvIZJ, m);
}

void Heavy_WSTD_DL3Y::cMsg_TWnK6x4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_YySozf1F_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YySozf1F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_mV4SUFdb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_omnVYcRW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_CSIs9fAK, m);
}

void Heavy_WSTD_DL3Y::cBinop_rJoihgtH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_c6fBw5ls_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_c6fBw5ls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ae3TMMZt, HV_BINOP_DIVIDE, 0, m, &cBinop_ae3TMMZt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ae3TMMZt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TWnK6x4z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_D7C4zKVf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_6gWaJqM7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6gWaJqM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_kjkpFMwM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_gySdkifa_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_bhwpJze7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_g4uzGd7K_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_A8CTrdcl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EMcpFPmx_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_EMcpFPmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_diWaZVJ6, HV_BINOP_DIVIDE, 1, m, &cBinop_diWaZVJ6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kjkpFMwM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_HcDOcpSo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HcDOcpSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_qIxhJsgt, m);
}

void Heavy_WSTD_DL3Y::cMsg_kXaEPWUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_cWBlqoT3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cWBlqoT3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_D7C4zKVf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gySdkifa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_tQiURUs4, m);
}

void Heavy_WSTD_DL3Y::cBinop_g4uzGd7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_VuZ0aG6o_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VuZ0aG6o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_diWaZVJ6, HV_BINOP_DIVIDE, 0, m, &cBinop_diWaZVJ6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_diWaZVJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kXaEPWUD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_m99HuQL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7lUGePv0, HV_BINOP_MULTIPLY, 0, m, &cBinop_7lUGePv0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_fKFrb83B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KgmF7Tox_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_KgmF7Tox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kUDoZlLx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_7lUGePv0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_NyTkMZPB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HdQxl5rp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7lUGePv0, HV_BINOP_MULTIPLY, 1, m, &cBinop_7lUGePv0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kUDoZlLx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_HdQxl5rp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NyTkMZPB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_grxMc3FL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_grxMc3FL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_cDSJYjqP_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_YMO7IlEL, m);
}

void Heavy_WSTD_DL3Y::cBinop_cDSJYjqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ljKnGqT9, m);
}

void Heavy_WSTD_DL3Y::cVar_8gafSZCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Y86FPIU, HV_BINOP_MULTIPLY, 0, m, &cBinop_2Y86FPIU_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qeMHxGyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xhABbkL2_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_xhABbkL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YJA83BrJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_2Y86FPIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Kp5uYKtY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aANKWVSj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Y86FPIU, HV_BINOP_MULTIPLY, 1, m, &cBinop_2Y86FPIU_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YJA83BrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_aANKWVSj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Kp5uYKtY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_VhmR1Iu5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VhmR1Iu5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ciM9u130_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_PDhT2aip, m);
}

void Heavy_WSTD_DL3Y::cBinop_ciM9u130_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_v0ldGHEL, m);
}

void Heavy_WSTD_DL3Y::sEnv_4qogAbA2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XFLsvZ2R_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VhWDigEk_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_TFNaY7dv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_3RWKhZsO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_iYIPBtga_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_zXD2No8o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gTFQmZF3, HV_BINOP_POW, 0, m, &cBinop_gTFQmZF3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gTFQmZF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R5gPBvM9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_zJ4w3Z1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_aANvb7D3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VhWDigEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TFNaY7dv, 0, m, &cIf_TFNaY7dv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XFLsvZ2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_yYydUc7Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yYydUc7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TFNaY7dv, 1, m, &cIf_TFNaY7dv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iYIPBtga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_zJ4w3Z1R_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3RWKhZsO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_R5gPBvM9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_aANvb7D3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gTFQmZF3, HV_BINOP_POW, 1, m, &cBinop_gTFQmZF3_sendMessage);
  cMsg_zXD2No8o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Hx7wVEbO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5guEBplm, HV_BINOP_MULTIPLY, 0, m, &cBinop_5guEBplm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_K2zOvOUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_yjjY2Atj_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_yjjY2Atj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CN6lM3B9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_5guEBplm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_PaFAU4cL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8GF6kt0A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5guEBplm, HV_BINOP_MULTIPLY, 1, m, &cBinop_5guEBplm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CN6lM3B9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8GF6kt0A_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PaFAU4cL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_AWS5U1Mh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AWS5U1Mh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_eRJJqJmZ_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_71QveUuE, m);
}

void Heavy_WSTD_DL3Y::cBinop_eRJJqJmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_wa34A2tM, m);
}

void Heavy_WSTD_DL3Y::cMsg_R5gPBvM9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_dRJZedQq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dRJZedQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_INsMxYSg, m);
}

void Heavy_WSTD_DL3Y::sEnv_K4IbXxoc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0udt6I22_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7WdMKtsO_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_72HndWDZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_AGDjhoBh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_MYNBCtCl_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_TTZx7kFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rXKQbkBQ, HV_BINOP_POW, 0, m, &cBinop_rXKQbkBQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rXKQbkBQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E87scrEw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_yDjSO2xM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_JN9Q7P26_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0udt6I22_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Z0RIN6oH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7WdMKtsO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_72HndWDZ, 0, m, &cIf_72HndWDZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Z0RIN6oH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_72HndWDZ, 1, m, &cIf_72HndWDZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MYNBCtCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_yDjSO2xM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_AGDjhoBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_E87scrEw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_JN9Q7P26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rXKQbkBQ, HV_BINOP_POW, 1, m, &cBinop_rXKQbkBQ_sendMessage);
  cMsg_TTZx7kFs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_8f3Pqlc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nBqiqbq5, HV_BINOP_MULTIPLY, 0, m, &cBinop_nBqiqbq5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZDQZuOv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QMFEorvC_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_QMFEorvC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6IZXSC6S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_nBqiqbq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_hy8lgCHt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4TnIItww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nBqiqbq5, HV_BINOP_MULTIPLY, 1, m, &cBinop_nBqiqbq5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6IZXSC6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_4TnIItww_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hy8lgCHt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_BhmiQNk0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BhmiQNk0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_h4tkFHik_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_pmMLYMUx, m);
}

void Heavy_WSTD_DL3Y::cBinop_h4tkFHik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_GMP0WMNK, m);
}

void Heavy_WSTD_DL3Y::cMsg_E87scrEw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_PH1jGw8w_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PH1jGw8w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_pn9tKd06, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Q2t2mJdc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zz3SbW4j, 0, m, &cSlice_zz3SbW4j_sendMessage);
      break;
    }
    default: {
      cSwitchcase_yiAzU76f_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_zz3SbW4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_2q1zCmgg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_2q1zCmgg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_s9NX3qqo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2q1zCmgg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_2q1zCmgg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dPx8wTm8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_YC47Gt28_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_u1dO6Zhu_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_u1dO6Zhu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_KvatKncn_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_MUzkcSJA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MUzkcSJA, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hFg83igd, 0, m, &cDelay_hFg83igd_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MUzkcSJA, 0, m, &cDelay_MUzkcSJA_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_PZ0ghr0m, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_hFg83igd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hFg83igd, m);
  cMsg_HBNXd3Du_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_8f0v6jAr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_MWEDTly5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_Is9dI2uv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NX0Ew2J5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_Tdkvhk3y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BjyFgcaR_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MUzkcSJA, 2, m, &cDelay_MUzkcSJA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xfYqViHV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NX0Ew2J5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_Tdkvhk3y, 0, m, &hTable_Tdkvhk3y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KvatKncn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_Is9dI2uv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HBNXd3Du_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_Tdkvhk3y, 0, m, &hTable_Tdkvhk3y_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xfYqViHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MUzkcSJA, 0, m, &cDelay_MUzkcSJA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BjyFgcaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_hFg83igd, 2, m, &cDelay_hFg83igd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MWEDTly5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_PZ0ghr0m, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_gJx0X160_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7JzSlYeh, HV_BINOP_SUBTRACT, 0, m, &cBinop_7JzSlYeh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rYJVR5iT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lB0mPOsh_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_lB0mPOsh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Irmz1rr6_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_rg6DXSsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O8ZSyPi4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_mehR0ZRO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mehR0ZRO, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PKhlc9gf, 0, m, &cDelay_PKhlc9gf_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_yLdSjCoK, 0, m, &sTabread_yLdSjCoK_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_PKhlc9gf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PKhlc9gf, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_yLdSjCoK, 0, m, &sTabread_yLdSjCoK_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PKhlc9gf, 0, m, &cDelay_PKhlc9gf_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_yLdSjCoK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_iyxFZsNq, HV_BINOP_SUBTRACT, 0, m, &cBinop_iyxFZsNq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_0vHEpVN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FnTNBUuf, HV_BINOP_MAX, 0, m, &cBinop_FnTNBUuf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Irmz1rr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0vHEpVN8, HV_BINOP_MULTIPLY, 0, m, &cBinop_0vHEpVN8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7JzSlYeh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FNzTZi1l_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_yLdSjCoK, 0, m, &sTabread_yLdSjCoK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xm8RLGjL_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_6UnAGKBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iyxFZsNq, HV_BINOP_SUBTRACT, 1, m, &cBinop_iyxFZsNq_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PKhlc9gf, 2, m, &cDelay_PKhlc9gf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_O8ZSyPi4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6UnAGKBg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FNzTZi1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_mehR0ZRO, 0, m, &cDelay_mehR0ZRO_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PKhlc9gf, 0, m, &cDelay_PKhlc9gf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Gu3uVJMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_FnTNBUuf, HV_BINOP_MAX, 1, m, &cBinop_FnTNBUuf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FnTNBUuf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7JzSlYeh, HV_BINOP_SUBTRACT, 1, m, &cBinop_7JzSlYeh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xm8RLGjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mehR0ZRO, 0, m, &cDelay_mehR0ZRO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1S9Qcuv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mehR0ZRO, 2, m, &cDelay_mehR0ZRO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iyxFZsNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_1S9Qcuv3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tAIOoZfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rg6DXSsy, 0, m, &cVar_rg6DXSsy_sendMessage);
  cMsg_rYJVR5iT_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_gJx0X160, 0, m, &cTabhead_gJx0X160_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rGR1wQtr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6k7jeH19_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_6k7jeH19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_H9ey4jib_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_WbOi1IDA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WbOi1IDA, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1QwPkM3X, 0, m, &cDelay_1QwPkM3X_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WbOi1IDA, 0, m, &cDelay_WbOi1IDA_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_WF3ks5yU, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_1QwPkM3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1QwPkM3X, m);
  cMsg_oZZrWETR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_UlNMf6k1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_qACYvQfW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_n5cdN3xV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_USqe3ftu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_dWUBVXGP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NTQFauYm_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WbOi1IDA, 2, m, &cDelay_WbOi1IDA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GmCg4JGU_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_USqe3ftu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_dWUBVXGP, 0, m, &hTable_dWUBVXGP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_H9ey4jib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_n5cdN3xV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oZZrWETR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_dWUBVXGP, 0, m, &hTable_dWUBVXGP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_GmCg4JGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WbOi1IDA, 0, m, &cDelay_WbOi1IDA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NTQFauYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_1QwPkM3X, 2, m, &cDelay_1QwPkM3X_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qACYvQfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_WF3ks5yU, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_o948jWOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vVbf8fD4, HV_BINOP_SUBTRACT, 0, m, &cBinop_vVbf8fD4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_22boBTwR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_eiHAper6_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_eiHAper6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_4t2M66X2_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_6UmO9q3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FbHqPO9A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_9rsSqxY5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9rsSqxY5, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_muWfJ5Ta, 0, m, &cDelay_muWfJ5Ta_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_jTcBTZVp, 0, m, &sTabread_jTcBTZVp_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_muWfJ5Ta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_muWfJ5Ta, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_jTcBTZVp, 0, m, &sTabread_jTcBTZVp_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_muWfJ5Ta, 0, m, &cDelay_muWfJ5Ta_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_jTcBTZVp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_wpy9S4O9, HV_BINOP_SUBTRACT, 0, m, &cBinop_wpy9S4O9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_mtq9595T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uuyfjePH, HV_BINOP_MAX, 0, m, &cBinop_uuyfjePH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4t2M66X2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mtq9595T, HV_BINOP_MULTIPLY, 0, m, &cBinop_mtq9595T_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vVbf8fD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O0BQWbET_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_jTcBTZVp, 0, m, &sTabread_jTcBTZVp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EqrcaY6s_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_h1qpKeep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wpy9S4O9, HV_BINOP_SUBTRACT, 1, m, &cBinop_wpy9S4O9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_muWfJ5Ta, 2, m, &cDelay_muWfJ5Ta_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FbHqPO9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_h1qpKeep_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_O0BQWbET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9rsSqxY5, 0, m, &cDelay_9rsSqxY5_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_muWfJ5Ta, 0, m, &cDelay_muWfJ5Ta_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_afH1FZHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_uuyfjePH, HV_BINOP_MAX, 1, m, &cBinop_uuyfjePH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uuyfjePH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vVbf8fD4, HV_BINOP_SUBTRACT, 1, m, &cBinop_vVbf8fD4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EqrcaY6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9rsSqxY5, 0, m, &cDelay_9rsSqxY5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JczKTGVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9rsSqxY5, 2, m, &cDelay_9rsSqxY5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wpy9S4O9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_JczKTGVK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dIoK9Ch9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6UmO9q3a, 0, m, &cVar_6UmO9q3a_sendMessage);
  cMsg_22boBTwR_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_o948jWOb, 0, m, &cTabhead_o948jWOb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_S9ngTDZd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_utSKmGDg, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_92URsiib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bLCuxmoW, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_mxcEgy7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wfxUkuYD, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_5yL8Bp2p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Twvj8aKn, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_4WjihsRh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iHsKI804, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_HwiTBmyx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4IuQTbbn, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Kz8ce5rc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oGq0VDwP, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_YFOnXzmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IQ7inc5L, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_4b8xTnFE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_C2bFMQDM, 0, m, &cSlice_C2bFMQDM_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_C2bFMQDM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_VtK1bqgS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_VtK1bqgS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_ojruipJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VtK1bqgS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_VtK1bqgS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0uNx3bey_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_vzX2oBxM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_SHnXfSmX, 0, m, &cSlice_SHnXfSmX_sendMessage);
      break;
    }
    default: {
      cSwitchcase_hIfDkCkv_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_SHnXfSmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_PPISVkls_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_PPISVkls_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_aP6sP9Af_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PPISVkls_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_PPISVkls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wv7AMngu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_o3wPWFRU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_FOt4HiNI, 0, m, &cSlice_FOt4HiNI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_4b8xTnFE_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_FOt4HiNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_bc15xNxw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_bc15xNxw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_aCG7YvSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bc15xNxw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_bc15xNxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_t02eVlBO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_H8MzQh0j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_gOZD2LBR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gOZD2LBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_FDXA8DZ3_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_CDFLDlXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UU1ZauAS_sendMessage(_c, 0, m);
  cMsg_qYHXBf76_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_dYW5cJrj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NWaL6iGj_sendMessage(_c, 0, m);
  cMsg_U020mcW1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_FDXA8DZ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Nz9Ghx4P_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Nz9Ghx4P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YBZ4bUPE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WqCmGmiU_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YBZ4bUPE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_zKd8OeFq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_WqCmGmiU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6rI5vWAg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_zKd8OeFq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_AFXp6Szs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6rI5vWAg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_j2wjpNoV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_j2wjpNoV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_duM5V0S5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AFXp6Szs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_CDFLDlXG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_duM5V0S5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_dYW5cJrj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Kgcs0uuM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_WKoKhA2F_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WKoKhA2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_v6g4q4fR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_v6g4q4fR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_aCRQ4Y9n_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aCRQ4Y9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sQyFp488_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Pp3689V8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Pp3689V8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O9wqVKvD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_sQyFp488_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_3eLNfqd9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3eLNfqd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_dP3IFCFY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_O9wqVKvD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_IAIQt0Jd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IAIQt0Jd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_QXSjNe1v_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QXSjNe1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H4gzpvoJ_sendMessage(_c, 0, m);
  cMsg_4rYMRcgC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_dP3IFCFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tHsp3imG_sendMessage(_c, 0, m);
  cMsg_xSPQJawP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_pbsg3cRa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Cx729lst_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Cx729lst_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_SwC6DzYh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_XtJAA6mu_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_IxkAjUtR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_tdasdu5A_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZyJrJ6GB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_k0n4FD4G_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_k0n4FD4G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_88yn1poG, HV_BINOP_DIVIDE, 1, m, &cBinop_88yn1poG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SwC6DzYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_BO3JP3s2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BO3JP3s2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_HvySZ8kd, m);
}

void Heavy_WSTD_DL3Y::cMsg_973jCID8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_kjelDfeL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kjelDfeL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_pbsg3cRa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XtJAA6mu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_PKwPEX0I, m);
}

void Heavy_WSTD_DL3Y::cBinop_tdasdu5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_1tpw7Jlj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1tpw7Jlj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_88yn1poG, HV_BINOP_DIVIDE, 0, m, &cBinop_88yn1poG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_88yn1poG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_973jCID8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_xT18TCgs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_yKeB54OD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yKeB54OD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_PRhu8uKF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_tK7QaALn_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_T6BQO7pv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_E2DLT6Yg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GC80J98l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_asfWUxJR_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_asfWUxJR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_l9KhrgzD, HV_BINOP_DIVIDE, 1, m, &cBinop_l9KhrgzD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PRhu8uKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_IsJznFmu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IsJznFmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_K2hlnLN3, m);
}

void Heavy_WSTD_DL3Y::cMsg_zCNJme4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_RTuXrm0e_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RTuXrm0e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_xT18TCgs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tK7QaALn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_cGNxohQa, m);
}

void Heavy_WSTD_DL3Y::cBinop_E2DLT6Yg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_FVJ1CZtJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FVJ1CZtJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_l9KhrgzD, HV_BINOP_DIVIDE, 0, m, &cBinop_l9KhrgzD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_l9KhrgzD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zCNJme4W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_5wHoJyT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Wxp9foq, HV_BINOP_MULTIPLY, 0, m, &cBinop_2Wxp9foq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_fXlQmrmP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8VtdbYs6_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_8VtdbYs6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nsJelnJT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_2Wxp9foq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ACzRrvLI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cvzA4zKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Wxp9foq, HV_BINOP_MULTIPLY, 1, m, &cBinop_2Wxp9foq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nsJelnJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_cvzA4zKj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ACzRrvLI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Fqy0GiTk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Fqy0GiTk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_dxBOp2OG_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_j1bSQNEb, m);
}

void Heavy_WSTD_DL3Y::cBinop_dxBOp2OG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_2XIPchpG, m);
}

void Heavy_WSTD_DL3Y::cVar_G6DZUdJX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IwyuYkjY, HV_BINOP_MULTIPLY, 0, m, &cBinop_IwyuYkjY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3cpvwJok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_g8z9hgsH_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_g8z9hgsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8JKXyVni_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_IwyuYkjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_uATSPQpc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bJGILxjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IwyuYkjY, HV_BINOP_MULTIPLY, 1, m, &cBinop_IwyuYkjY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8JKXyVni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_bJGILxjn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uATSPQpc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_M5oBJwP7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_M5oBJwP7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_3qxKPHom_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_fQAyb3if, m);
}

void Heavy_WSTD_DL3Y::cBinop_3qxKPHom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_t9J0x4Lq, m);
}

void Heavy_WSTD_DL3Y::sEnv_UKnxZEUt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dEcWPVu8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KoB7O9p0_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_D6YE0FKL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_yZHKr7BF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_u0MUhZMN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_Nh7ZEaY1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8FlYGX1D, HV_BINOP_POW, 0, m, &cBinop_8FlYGX1D_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8FlYGX1D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1j1VVI3G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_lAT32r3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_q2ALO25t_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KoB7O9p0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_D6YE0FKL, 0, m, &cIf_D6YE0FKL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dEcWPVu8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_bKjEenCw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bKjEenCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_D6YE0FKL, 1, m, &cIf_D6YE0FKL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_u0MUhZMN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_lAT32r3x_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yZHKr7BF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_1j1VVI3G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_q2ALO25t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8FlYGX1D, HV_BINOP_POW, 1, m, &cBinop_8FlYGX1D_sendMessage);
  cMsg_Nh7ZEaY1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_06Jdk9i8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4Ntd1sT1, HV_BINOP_MULTIPLY, 0, m, &cBinop_4Ntd1sT1_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cggSMTWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0AmPHfGG_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_0AmPHfGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_73fcMTi0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_4Ntd1sT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_BEpzwllo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LpdL4VlE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4Ntd1sT1, HV_BINOP_MULTIPLY, 1, m, &cBinop_4Ntd1sT1_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_73fcMTi0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_LpdL4VlE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BEpzwllo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_5yNUkAUW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5yNUkAUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_cYPaII6i_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_oroFNGcd, m);
}

void Heavy_WSTD_DL3Y::cBinop_cYPaII6i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_jIJJgEol, m);
}

void Heavy_WSTD_DL3Y::cMsg_1j1VVI3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_wrPY3lsc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wrPY3lsc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_2cH5tQpI, m);
}

void Heavy_WSTD_DL3Y::sEnv_9KD2wR6y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PdkNLB5S_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_prZRNwjv_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_kBbDWfrZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_5tPsrfgl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_Jovhlzwh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_mnG3BDDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_QHGsMQaE, HV_BINOP_POW, 0, m, &cBinop_QHGsMQaE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QHGsMQaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2c0QuxW3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_LqXbcsNp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_NTERC0zP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_PdkNLB5S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_r8VO4vWs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_prZRNwjv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kBbDWfrZ, 0, m, &cIf_kBbDWfrZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_r8VO4vWs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kBbDWfrZ, 1, m, &cIf_kBbDWfrZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Jovhlzwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_LqXbcsNp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5tPsrfgl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_2c0QuxW3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_NTERC0zP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QHGsMQaE, HV_BINOP_POW, 1, m, &cBinop_QHGsMQaE_sendMessage);
  cMsg_mnG3BDDs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_79mHy3TD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HqhktPo2, HV_BINOP_MULTIPLY, 0, m, &cBinop_HqhktPo2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_s8Wb6DHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ozHPEpSn_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ozHPEpSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NWyUunhW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_HqhktPo2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_jPbUluR2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GZMB3zq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HqhktPo2, HV_BINOP_MULTIPLY, 1, m, &cBinop_HqhktPo2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NWyUunhW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_GZMB3zq4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jPbUluR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_gERpQgfH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gERpQgfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_N632lXtq_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_apWh2XYR, m);
}

void Heavy_WSTD_DL3Y::cBinop_N632lXtq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_yFeKyiFF, m);
}

void Heavy_WSTD_DL3Y::cMsg_2c0QuxW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_JFLPOVdx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JFLPOVdx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ceX3I6Pm, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_hIfDkCkv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ZzoIGJiu, 0, m, &cSlice_ZzoIGJiu_sendMessage);
      break;
    }
    default: {
      cSwitchcase_o3wPWFRU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_ZzoIGJiu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_TyHW2geA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_TyHW2geA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_FEBZkrUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TyHW2geA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_TyHW2geA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nxasNClf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_L4lqoUqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_p5AAGHAX_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_p5AAGHAX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_hYnqceqq_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_It2DQ3al_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_It2DQ3al, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2RHdwjE6, 0, m, &cDelay_2RHdwjE6_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_It2DQ3al, 0, m, &cDelay_It2DQ3al_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_6jewWSxb, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_2RHdwjE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2RHdwjE6, m);
  cMsg_qGAFEdQY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_zllt9yW4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_GrZOgpMz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_2I01G8Bc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KbkhDPPf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_ExmUbeIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6CxDAwQz_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_It2DQ3al, 2, m, &cDelay_It2DQ3al_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iHBvuVEb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KbkhDPPf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_ExmUbeIJ, 0, m, &hTable_ExmUbeIJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hYnqceqq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_2I01G8Bc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qGAFEdQY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_ExmUbeIJ, 0, m, &hTable_ExmUbeIJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_iHBvuVEb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_It2DQ3al, 0, m, &cDelay_It2DQ3al_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6CxDAwQz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_2RHdwjE6, 2, m, &cDelay_2RHdwjE6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GrZOgpMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_6jewWSxb, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_2pTjEii2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4IQtwCC7, HV_BINOP_SUBTRACT, 0, m, &cBinop_4IQtwCC7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1HhWRUDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bjzFYcgn_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_bjzFYcgn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_EFF5MuB0_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_HwvrKiZy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2EffJ4bo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_W4P0Bzyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_W4P0Bzyf, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6frF5PaN, 0, m, &cDelay_6frF5PaN_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_mvrlFkTa, 0, m, &sTabread_mvrlFkTa_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_6frF5PaN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6frF5PaN, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_mvrlFkTa, 0, m, &sTabread_mvrlFkTa_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6frF5PaN, 0, m, &cDelay_6frF5PaN_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_mvrlFkTa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_LBqsb6y0, HV_BINOP_SUBTRACT, 0, m, &cBinop_LBqsb6y0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_WvArmTSc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UQkR7FyD, HV_BINOP_MAX, 0, m, &cBinop_UQkR7FyD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EFF5MuB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WvArmTSc, HV_BINOP_MULTIPLY, 0, m, &cBinop_WvArmTSc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4IQtwCC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m67jjHCJ_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_mvrlFkTa, 0, m, &sTabread_mvrlFkTa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y9LLuzB0_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_6iGklUYl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LBqsb6y0, HV_BINOP_SUBTRACT, 1, m, &cBinop_LBqsb6y0_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6frF5PaN, 2, m, &cDelay_6frF5PaN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2EffJ4bo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6iGklUYl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_m67jjHCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_W4P0Bzyf, 0, m, &cDelay_W4P0Bzyf_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6frF5PaN, 0, m, &cDelay_6frF5PaN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pYIvUrNw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_UQkR7FyD, HV_BINOP_MAX, 1, m, &cBinop_UQkR7FyD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UQkR7FyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4IQtwCC7, HV_BINOP_SUBTRACT, 1, m, &cBinop_4IQtwCC7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_y9LLuzB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_W4P0Bzyf, 0, m, &cDelay_W4P0Bzyf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GVeM9wqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_W4P0Bzyf, 2, m, &cDelay_W4P0Bzyf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LBqsb6y0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_GVeM9wqc_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_N5684Gc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HwvrKiZy, 0, m, &cVar_HwvrKiZy_sendMessage);
  cMsg_1HhWRUDo_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_2pTjEii2, 0, m, &cTabhead_2pTjEii2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_m65gghvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MVCnMLFi_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_MVCnMLFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_tNXvntKp_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_w42nRnWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_w42nRnWh, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FpLWQE9o, 0, m, &cDelay_FpLWQE9o_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_w42nRnWh, 0, m, &cDelay_w42nRnWh_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_xqQF5wro, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_FpLWQE9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FpLWQE9o, m);
  cMsg_AY79PVkb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_cN0kq3GP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_cWYoqutW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_gnVU5HeF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4rfqLi1J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_JQ53cYuw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Kz4cPUAZ_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_w42nRnWh, 2, m, &cDelay_w42nRnWh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qDUmL7i0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4rfqLi1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_JQ53cYuw, 0, m, &hTable_JQ53cYuw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tNXvntKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_gnVU5HeF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_AY79PVkb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_JQ53cYuw, 0, m, &hTable_JQ53cYuw_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qDUmL7i0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_w42nRnWh, 0, m, &cDelay_w42nRnWh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Kz4cPUAZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_FpLWQE9o, 2, m, &cDelay_FpLWQE9o_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cWYoqutW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_xqQF5wro, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_FUifxdjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ENff13kt, HV_BINOP_SUBTRACT, 0, m, &cBinop_ENff13kt_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_n4niBbml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_epWLBjFO_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_epWLBjFO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Pd6p2mBt_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_jMqXPRBZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jWIBhShA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_C0ZoZRZz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_C0ZoZRZz, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AG1d21aw, 0, m, &cDelay_AG1d21aw_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_bq6wfG3C, 0, m, &sTabread_bq6wfG3C_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_AG1d21aw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AG1d21aw, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_bq6wfG3C, 0, m, &sTabread_bq6wfG3C_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AG1d21aw, 0, m, &cDelay_AG1d21aw_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_bq6wfG3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_a0LFPGxO, HV_BINOP_SUBTRACT, 0, m, &cBinop_a0LFPGxO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_3keyEG44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ONsXkYzG, HV_BINOP_MAX, 0, m, &cBinop_ONsXkYzG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Pd6p2mBt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3keyEG44, HV_BINOP_MULTIPLY, 0, m, &cBinop_3keyEG44_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ENff13kt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IgvIZxLw_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_bq6wfG3C, 0, m, &sTabread_bq6wfG3C_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G3jUEL3x_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_MSWs7vLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a0LFPGxO, HV_BINOP_SUBTRACT, 1, m, &cBinop_a0LFPGxO_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AG1d21aw, 2, m, &cDelay_AG1d21aw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jWIBhShA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MSWs7vLp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IgvIZxLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_C0ZoZRZz, 0, m, &cDelay_C0ZoZRZz_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AG1d21aw, 0, m, &cDelay_AG1d21aw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XfkJg9gf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_ONsXkYzG, HV_BINOP_MAX, 1, m, &cBinop_ONsXkYzG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ONsXkYzG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ENff13kt, HV_BINOP_SUBTRACT, 1, m, &cBinop_ENff13kt_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_G3jUEL3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_C0ZoZRZz, 0, m, &cDelay_C0ZoZRZz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_D5QM5YEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_C0ZoZRZz, 2, m, &cDelay_C0ZoZRZz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_a0LFPGxO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_D5QM5YEV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0OnoMTLz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jMqXPRBZ, 0, m, &cVar_jMqXPRBZ_sendMessage);
  cMsg_n4niBbml_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_FUifxdjL, 0, m, &cTabhead_FUifxdjL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UU1ZauAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Fb3CgQop, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_NWaL6iGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8iVM7Tlz, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_U020mcW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MMX20r1Q, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_qYHXBf76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tD2vcfSh, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_xSPQJawP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kJnqDVux, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_H4gzpvoJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_miEqcGzl, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_tHsp3imG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jaKaOK2j, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_4rYMRcgC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Bnrp9H72, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_z7iOQrQb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_y7q8YURr, 0, m, &cSlice_y7q8YURr_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_y7q8YURr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rOYLAzPF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rOYLAzPF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_z3nozhED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rOYLAzPF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_rOYLAzPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9HRPrj22_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_PajKgo6N_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1nObwOGU, 0, m, &cSlice_1nObwOGU_sendMessage);
      break;
    }
    default: {
      cSwitchcase_7bMncMu9_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_1nObwOGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ZDFDIksZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ZDFDIksZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_8ta5rOTh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZDFDIksZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_ZDFDIksZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_F3Li0fNB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_8GQM8jgH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_pPHX2kaM, 0, m, &cSlice_pPHX2kaM_sendMessage);
      break;
    }
    default: {
      cSwitchcase_z7iOQrQb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_pPHX2kaM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_HhYwDsSY_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_HhYwDsSY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_ennIrtAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HhYwDsSY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_HhYwDsSY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9gNJyThY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_eGXbEPn3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_IeyK5qra_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IeyK5qra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_4GG6m6ft_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_V5jXcyHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y7lBHzXr_sendMessage(_c, 0, m);
  cMsg_zWukdo84_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_CTA4Hblt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CwtLhj5o_sendMessage(_c, 0, m);
  cMsg_2z71CzZ0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_4GG6m6ft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_NufENY8m_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NufENY8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kivnzcl8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tdE9bl2k_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tdE9bl2k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VabsCA9Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_kivnzcl8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_UD2EJHm1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UD2EJHm1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7crCkMVV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VabsCA9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_qm7VQJ44_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qm7VQJ44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_I7YXlDzv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7crCkMVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_V5jXcyHb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_I7YXlDzv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_CTA4Hblt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LLUfySdV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_aXeZcBCo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aXeZcBCo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_IW9qvoaS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IW9qvoaS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_R1fGwYOx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_R1fGwYOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1azETIfY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jQT00Uuc_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jQT00Uuc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IDKYPcCp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_1azETIfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_JTpTWkQK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JTpTWkQK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_R8BbKLWP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IDKYPcCp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_TZnZKGSg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TZnZKGSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_8UDKm8Ai_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8UDKm8Ai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RkmBQvb0_sendMessage(_c, 0, m);
  cMsg_td2Bwodt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_R8BbKLWP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wt8mku3Z_sendMessage(_c, 0, m);
  cMsg_qMbeYk99_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_nAJcmgbD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_CxukT8x4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CxukT8x4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ibV3VMhc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_TGu4ka7X_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_wETjFAOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_sRV7TD4M_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bmkgH7EF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_adevI3TW_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_adevI3TW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kdp7DS42, HV_BINOP_DIVIDE, 1, m, &cBinop_Kdp7DS42_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ibV3VMhc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_4fBJR6P1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4fBJR6P1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_I5IjzmZh, m);
}

void Heavy_WSTD_DL3Y::cMsg_swcK6FBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_4xqvkySk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4xqvkySk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_nAJcmgbD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TGu4ka7X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_jmd58Q9e, m);
}

void Heavy_WSTD_DL3Y::cBinop_sRV7TD4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_0dskOrQ4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0dskOrQ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kdp7DS42, HV_BINOP_DIVIDE, 0, m, &cBinop_Kdp7DS42_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Kdp7DS42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_swcK6FBv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_eDvUU3R9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_qkLrMKJk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qkLrMKJk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_7EnFNRqI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_852lm0nn_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_U3tCEwTp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_gqLMwkaf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wkugLWtY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nZIrkmWD_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_nZIrkmWD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xNxHPKNZ, HV_BINOP_DIVIDE, 1, m, &cBinop_xNxHPKNZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7EnFNRqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0xUeZTPI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0xUeZTPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_5kqZopWZ, m);
}

void Heavy_WSTD_DL3Y::cMsg_2EdgLhsG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_7Lp677fG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7Lp677fG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_eDvUU3R9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_852lm0nn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_CHIUgKtc, m);
}

void Heavy_WSTD_DL3Y::cBinop_gqLMwkaf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_4zENuWQ2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4zENuWQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xNxHPKNZ, HV_BINOP_DIVIDE, 0, m, &cBinop_xNxHPKNZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xNxHPKNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2EdgLhsG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_gI6eCAop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_icjT6bh1, HV_BINOP_MULTIPLY, 0, m, &cBinop_icjT6bh1_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YAxusiPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GpOvDR7z_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_GpOvDR7z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k54hOfjX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_icjT6bh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_JvNyF2KK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Bl6c99WY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_icjT6bh1, HV_BINOP_MULTIPLY, 1, m, &cBinop_icjT6bh1_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_k54hOfjX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Bl6c99WY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JvNyF2KK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_xCZCgwYL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xCZCgwYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_t7pFGXZe_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_6N9xixoS, m);
}

void Heavy_WSTD_DL3Y::cBinop_t7pFGXZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Ppdm7b6C, m);
}

void Heavy_WSTD_DL3Y::cVar_khRxwZYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aLMRAXNc, HV_BINOP_MULTIPLY, 0, m, &cBinop_aLMRAXNc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hc7kfRh8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RL2zrL7p_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_RL2zrL7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5UF68PTD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_aLMRAXNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_C5kX88lV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EZR7MXiN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aLMRAXNc, HV_BINOP_MULTIPLY, 1, m, &cBinop_aLMRAXNc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5UF68PTD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_EZR7MXiN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_C5kX88lV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_7aCPhAEQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7aCPhAEQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_YCipK3gG_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_0LbwuWxx, m);
}

void Heavy_WSTD_DL3Y::cBinop_YCipK3gG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_2nTN6fGk, m);
}

void Heavy_WSTD_DL3Y::sEnv_jtn9H55R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4oBMc7wi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M5mSfJTX_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_dWzAIAQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_jrLYua3U_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_BMK7sl6f_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_6OhunMTO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ySYnt1lD, HV_BINOP_POW, 0, m, &cBinop_ySYnt1lD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ySYnt1lD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LHkAYxih_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_AHAnQtia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_5SrGZAeI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_M5mSfJTX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dWzAIAQT, 0, m, &cIf_dWzAIAQT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4oBMc7wi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_B3sLXqVm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_B3sLXqVm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dWzAIAQT, 1, m, &cIf_dWzAIAQT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BMK7sl6f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_AHAnQtia_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jrLYua3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_LHkAYxih_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_5SrGZAeI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ySYnt1lD, HV_BINOP_POW, 1, m, &cBinop_ySYnt1lD_sendMessage);
  cMsg_6OhunMTO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_X4B58Xcp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jZvAe5hb, HV_BINOP_MULTIPLY, 0, m, &cBinop_jZvAe5hb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Ow8tcuQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fKWOvaNt_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_fKWOvaNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DXyFSRYY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_jZvAe5hb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_A9VqIExg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hHzrGFHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jZvAe5hb, HV_BINOP_MULTIPLY, 1, m, &cBinop_jZvAe5hb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DXyFSRYY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_hHzrGFHB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_A9VqIExg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_llhIgc44_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_llhIgc44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_zNi7EXu4_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_FkJRdlvA, m);
}

void Heavy_WSTD_DL3Y::cBinop_zNi7EXu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_IZBsLiYf, m);
}

void Heavy_WSTD_DL3Y::cMsg_LHkAYxih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_RwbiRU4L_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RwbiRU4L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_E8WGpvdP, m);
}

void Heavy_WSTD_DL3Y::sEnv_4e45RP5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MD4kVAIR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GGxnR3cY_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_JjZEs06u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_A2tt4AGA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_HJuxInkg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_D7nm5X3E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_tt2wlCFL, HV_BINOP_POW, 0, m, &cBinop_tt2wlCFL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tt2wlCFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QggpEX25_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_9nzRKGfG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_2nqafXFK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_GGxnR3cY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JjZEs06u, 0, m, &cIf_JjZEs06u_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_MD4kVAIR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_OI5zxuvG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OI5zxuvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JjZEs06u, 1, m, &cIf_JjZEs06u_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HJuxInkg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_9nzRKGfG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_A2tt4AGA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_QggpEX25_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_2nqafXFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tt2wlCFL, HV_BINOP_POW, 1, m, &cBinop_tt2wlCFL_sendMessage);
  cMsg_D7nm5X3E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_a8WDOYXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QJPFh2wl, HV_BINOP_MULTIPLY, 0, m, &cBinop_QJPFh2wl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Y74Z3VZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_q1Pz18jI_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_q1Pz18jI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rE4SuNAz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_QJPFh2wl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ADoO73Qh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lCBV7wAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QJPFh2wl, HV_BINOP_MULTIPLY, 1, m, &cBinop_QJPFh2wl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rE4SuNAz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_lCBV7wAl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ADoO73Qh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_4f4NWY3Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4f4NWY3Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_M3ivRHiX_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_4MgL4vKE, m);
}

void Heavy_WSTD_DL3Y::cBinop_M3ivRHiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_9oIIFQlZ, m);
}

void Heavy_WSTD_DL3Y::cMsg_QggpEX25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_RvAQc0xu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RvAQc0xu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_TPjdyPHS, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_7bMncMu9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_YX0Spn8y, 0, m, &cSlice_YX0Spn8y_sendMessage);
      break;
    }
    default: {
      cSwitchcase_8GQM8jgH_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_YX0Spn8y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JyGBls2J_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JyGBls2J_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_OGdAaZmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JyGBls2J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_JyGBls2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TJD4nbWL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_y0WFTjSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ohAXOMab_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ohAXOMab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_RkgbM0By_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_6Jt0odZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6Jt0odZb, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kJa7jeEw, 0, m, &cDelay_kJa7jeEw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6Jt0odZb, 0, m, &cDelay_6Jt0odZb_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_zFlFCvWn, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_kJa7jeEw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kJa7jeEw, m);
  cMsg_deGyvPli_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_4GIwry0d_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_G6Dhz7De_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_8VJaB4UP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jNAxSZsQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_DmQuzStW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hPJUM4vB_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6Jt0odZb, 2, m, &cDelay_6Jt0odZb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oRK2hBGQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jNAxSZsQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_DmQuzStW, 0, m, &hTable_DmQuzStW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RkgbM0By_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_8VJaB4UP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_deGyvPli_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_DmQuzStW, 0, m, &hTable_DmQuzStW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_oRK2hBGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6Jt0odZb, 0, m, &cDelay_6Jt0odZb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hPJUM4vB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_kJa7jeEw, 2, m, &cDelay_kJa7jeEw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_G6Dhz7De_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_zFlFCvWn, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_ykw58UG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rWipsGoS, HV_BINOP_SUBTRACT, 0, m, &cBinop_rWipsGoS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qIAt7pbh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hMVCLihn_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_hMVCLihn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_5ZOk9UWp_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_BQDWME4k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tIPzxY8v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_fUcNu2hR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fUcNu2hR, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dRsZqUJx, 0, m, &cDelay_dRsZqUJx_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_dlR63vCu, 0, m, &sTabread_dlR63vCu_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_dRsZqUJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dRsZqUJx, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_dlR63vCu, 0, m, &sTabread_dlR63vCu_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dRsZqUJx, 0, m, &cDelay_dRsZqUJx_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_dlR63vCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_JULe2pX5, HV_BINOP_SUBTRACT, 0, m, &cBinop_JULe2pX5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_0BGtaNGi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lbph2uJj, HV_BINOP_MAX, 0, m, &cBinop_Lbph2uJj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5ZOk9UWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0BGtaNGi, HV_BINOP_MULTIPLY, 0, m, &cBinop_0BGtaNGi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rWipsGoS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_miLdLG44_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_dlR63vCu, 0, m, &sTabread_dlR63vCu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8EwqdRMf_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_N0m54muX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JULe2pX5, HV_BINOP_SUBTRACT, 1, m, &cBinop_JULe2pX5_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dRsZqUJx, 2, m, &cDelay_dRsZqUJx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tIPzxY8v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_N0m54muX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_miLdLG44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fUcNu2hR, 0, m, &cDelay_fUcNu2hR_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dRsZqUJx, 0, m, &cDelay_dRsZqUJx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WjyK5a9G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lbph2uJj, HV_BINOP_MAX, 1, m, &cBinop_Lbph2uJj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Lbph2uJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rWipsGoS, HV_BINOP_SUBTRACT, 1, m, &cBinop_rWipsGoS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8EwqdRMf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fUcNu2hR, 0, m, &cDelay_fUcNu2hR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1zemQeAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fUcNu2hR, 2, m, &cDelay_fUcNu2hR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JULe2pX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_1zemQeAR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8X0I6Q9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BQDWME4k, 0, m, &cVar_BQDWME4k_sendMessage);
  cMsg_qIAt7pbh_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ykw58UG0, 0, m, &cTabhead_ykw58UG0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7vjoAodb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZAdjzljL_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ZAdjzljL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_DcqLIF8N_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_CLJq33tF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CLJq33tF, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WFtsTgmu, 0, m, &cDelay_WFtsTgmu_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CLJq33tF, 0, m, &cDelay_CLJq33tF_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_VXpSlNKB, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_WFtsTgmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WFtsTgmu, m);
  cMsg_F62Q3b0L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_4V4VFiZH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_NWpOKojM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_RVpeq08L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yvFSjSZa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_g879XfQC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KeVgT7xX_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CLJq33tF, 2, m, &cDelay_CLJq33tF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jVTTkWNg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yvFSjSZa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_g879XfQC, 0, m, &hTable_g879XfQC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DcqLIF8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_RVpeq08L_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_F62Q3b0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_g879XfQC, 0, m, &hTable_g879XfQC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jVTTkWNg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CLJq33tF, 0, m, &cDelay_CLJq33tF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KeVgT7xX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_WFtsTgmu, 2, m, &cDelay_WFtsTgmu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NWpOKojM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_VXpSlNKB, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_3g3CQxeW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iUwBd6V0, HV_BINOP_SUBTRACT, 0, m, &cBinop_iUwBd6V0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IUnuRkzG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_L0N4vb1v_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_L0N4vb1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_2aKI2izh_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_tKu2rfdg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o7sikHG8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_AjEqvswW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AjEqvswW, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6hikNmJS, 0, m, &cDelay_6hikNmJS_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_99Js78VF, 0, m, &sTabread_99Js78VF_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_6hikNmJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6hikNmJS, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_99Js78VF, 0, m, &sTabread_99Js78VF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6hikNmJS, 0, m, &cDelay_6hikNmJS_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_99Js78VF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_WvkM6ASI, HV_BINOP_SUBTRACT, 0, m, &cBinop_WvkM6ASI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_U557CEPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aV0zlqWv, HV_BINOP_MAX, 0, m, &cBinop_aV0zlqWv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2aKI2izh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U557CEPr, HV_BINOP_MULTIPLY, 0, m, &cBinop_U557CEPr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iUwBd6V0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JxoHwFba_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_99Js78VF, 0, m, &sTabread_99Js78VF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WdRf8hDz_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_o2kZFALQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WvkM6ASI, HV_BINOP_SUBTRACT, 1, m, &cBinop_WvkM6ASI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6hikNmJS, 2, m, &cDelay_6hikNmJS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_o7sikHG8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_o2kZFALQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JxoHwFba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AjEqvswW, 0, m, &cDelay_AjEqvswW_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6hikNmJS, 0, m, &cDelay_6hikNmJS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_t432WEtl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_aV0zlqWv, HV_BINOP_MAX, 1, m, &cBinop_aV0zlqWv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aV0zlqWv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iUwBd6V0, HV_BINOP_SUBTRACT, 1, m, &cBinop_iUwBd6V0_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_WdRf8hDz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AjEqvswW, 0, m, &cDelay_AjEqvswW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QT9XckgI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AjEqvswW, 2, m, &cDelay_AjEqvswW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WvkM6ASI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_QT9XckgI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LjtJX1eB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tKu2rfdg, 0, m, &cVar_tKu2rfdg_sendMessage);
  cMsg_IUnuRkzG_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_3g3CQxeW, 0, m, &cTabhead_3g3CQxeW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Y7lBHzXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eOJnaWpJ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_CwtLhj5o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_URkDQfHZ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_2z71CzZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IqdsTprS, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_zWukdo84_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Fkm2zs7P, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_qMbeYk99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fLPL752l, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_RkmBQvb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0OcbbiF9, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_wt8mku3Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mgVqi2NH, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_td2Bwodt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_x7HYKtqm, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cVar_pRG0OfjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AWmiyPG7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OuBgZwYN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_F0pR8j0S_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AWmiyPG7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pRG0OfjE, 1, m, &cVar_pRG0OfjE_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_DUYmtJAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_0ddi3Qld, 0, m, &cVar_0ddi3Qld_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_8b8XU3gr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_0ddi3Qld, 0, m, &cVar_0ddi3Qld_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_kmQQXUnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8b8XU3gr, 0, m, &cIf_8b8XU3gr_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_VHTQOXFX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DUYmtJAs, 0, m, &cIf_DUYmtJAs_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_CCRFu9ju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BEcP03Vt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FTQwsRsv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_clkshj8S_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BEcP03Vt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CCRFu9ju, 1, m, &cVar_CCRFu9ju_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_yoSjmVvg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_n6r9BSz5, 0, m, &cVar_n6r9BSz5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_1z4OrrVx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_n6r9BSz5, 0, m, &cVar_n6r9BSz5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_wLiHOiSv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1z4OrrVx, 0, m, &cIf_1z4OrrVx_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_fAHXgocj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yoSjmVvg, 0, m, &cIf_yoSjmVvg_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_S4gmapW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_W8yBjbmn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VJN192wg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_CtkFcFIc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_W8yBjbmn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_S4gmapW3, 1, m, &cVar_S4gmapW3_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_Ho6LZp4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_wcXCsTCN, 0, m, &cVar_wcXCsTCN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_T1r9vE6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_wcXCsTCN, 0, m, &cVar_wcXCsTCN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_Pdwn4J3F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T1r9vE6w, 0, m, &cIf_T1r9vE6w_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_LwxuYIQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ho6LZp4F, 0, m, &cIf_Ho6LZp4F_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_CEjjQhBW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WwL5Rbe8, HV_BINOP_DIVIDE, 0, m, &cBinop_WwL5Rbe8_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_MXBEdkKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yTGaFW7g, HV_BINOP_MULTIPLY, 1, m, &cBinop_yTGaFW7g_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_rOllSQsC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_thp5J8zs, 0, m, &cSlice_thp5J8zs_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_f7RE54SZ, 0, m, &cSlice_f7RE54SZ_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cQqL0b5U_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2Sz3ihTc_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_thp5J8zs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_imrb104C, 0, m, &cVar_imrb104C_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_imrb104C, 0, m, &cVar_imrb104C_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_f7RE54SZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_nYl5QiIs, HV_BINOP_NEQ, 1, m, &cBinop_nYl5QiIs_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_imrb104C, 1, m, &cVar_imrb104C_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_nYl5QiIs, HV_BINOP_NEQ, 1, m, &cBinop_nYl5QiIs_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_imrb104C, 1, m, &cVar_imrb104C_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_imrb104C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_QFJMGZXA_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_ZKrLSV0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gddd4Pfi_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4rQadMRE_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_4rQadMRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_imrb104C, 0, m, &cVar_imrb104C_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gddd4Pfi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nYl5QiIs, HV_BINOP_NEQ, 1, m, &cBinop_nYl5QiIs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nYl5QiIs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZKrLSV0i, 1, m, &cIf_ZKrLSV0i_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cQqL0b5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nYl5QiIs, HV_BINOP_NEQ, 0, m, &cBinop_nYl5QiIs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_2Sz3ihTc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZKrLSV0i, 0, m, &cIf_ZKrLSV0i_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_CCbN6szz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uXNNQMSW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hEgUxXUM_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Quu3yEGN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k7xYy3ah_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OAxBMhc0_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sEFvIMKw_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Dw2VtHRw_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8Qv55Ljb_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qRcK4um5_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FvXNFKFm_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sLRh1PNg_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sse9RtCK_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9HadTDwn_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XAG8ovHv_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D0WnF8Rs_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ViYu7Lgx_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_k7xYy3ah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Xz3qzYRe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_OAxBMhc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WFQ5Dah0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_sEFvIMKw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_42mFzgU5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Dw2VtHRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rwtfSUJN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_8Qv55Ljb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uOMkTqz7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_qRcK4um5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YLRDZDOt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_FvXNFKFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1ChDiziC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_sLRh1PNg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_25gGVn9W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_sse9RtCK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Tgtjdb3e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_9HadTDwn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OhyJp8Bv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_XAG8ovHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DSee7teC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_D0WnF8Rs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2SsfSfGX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ViYu7Lgx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IgYA3s4V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_WwL5Rbe8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yTGaFW7g, HV_BINOP_MULTIPLY, 0, m, &cBinop_yTGaFW7g_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yTGaFW7g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_rOllSQsC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_uXNNQMSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WwL5Rbe8, HV_BINOP_DIVIDE, 1, m, &cBinop_WwL5Rbe8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hEgUxXUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CEjjQhBW, 0, m, &cVar_CEjjQhBW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MXBEdkKs, 0, m, &cVar_MXBEdkKs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1NDmMRDx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CEjjQhBW, 0, m, &cVar_CEjjQhBW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_eaaCMCX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MXBEdkKs, 0, m, &cVar_MXBEdkKs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Xz3qzYRe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eaaCMCX4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1NDmMRDx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WFQ5Dah0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eaaCMCX4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1NDmMRDx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_42mFzgU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eaaCMCX4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1NDmMRDx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rwtfSUJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eaaCMCX4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1NDmMRDx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uOMkTqz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eaaCMCX4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1NDmMRDx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YLRDZDOt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eaaCMCX4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1NDmMRDx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1ChDiziC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eaaCMCX4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1NDmMRDx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_25gGVn9W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eaaCMCX4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1NDmMRDx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Tgtjdb3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eaaCMCX4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1NDmMRDx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OhyJp8Bv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eaaCMCX4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1NDmMRDx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DSee7teC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eaaCMCX4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1NDmMRDx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2SsfSfGX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eaaCMCX4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1NDmMRDx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IgYA3s4V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eaaCMCX4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1NDmMRDx_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_60JmJSYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ykWyMoLz, HV_BINOP_DIVIDE, 0, m, &cBinop_ykWyMoLz_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_yK5HW2gy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ao4VTc2n, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ao4VTc2n_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_FEchXAp2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qeh5wPst, 0, m, &cSlice_qeh5wPst_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XUTgxZKR, 0, m, &cSlice_XUTgxZKR_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B1jBXFA8_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xKxejVZ2_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_qeh5wPst_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_wDB4J7lp, 0, m, &cVar_wDB4J7lp_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_wDB4J7lp, 0, m, &cVar_wDB4J7lp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_XUTgxZKR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_ClIFezc2, HV_BINOP_NEQ, 1, m, &cBinop_ClIFezc2_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_wDB4J7lp, 1, m, &cVar_wDB4J7lp_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_ClIFezc2, HV_BINOP_NEQ, 1, m, &cBinop_ClIFezc2_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_wDB4J7lp, 1, m, &cVar_wDB4J7lp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_wDB4J7lp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_flDGtR7Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_dcD6CUhi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MzgUMakR_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T0EugE93_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_MzgUMakR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ClIFezc2, HV_BINOP_NEQ, 1, m, &cBinop_ClIFezc2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_T0EugE93_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wDB4J7lp, 0, m, &cVar_wDB4J7lp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ClIFezc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dcD6CUhi, 1, m, &cIf_dcD6CUhi_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_B1jBXFA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ClIFezc2, HV_BINOP_NEQ, 0, m, &cBinop_ClIFezc2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xKxejVZ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dcD6CUhi, 0, m, &cIf_dcD6CUhi_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_nUlc5jzB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vix1fUKo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IAKfiYgt_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_YR5Jsy5B_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BwhLLaeV_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WfcAY7TU_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pBzv2pUe_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Tt7xtC0z_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6CxwiYDO_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Hr7rDV41_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5KKjTfJu_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WMI6sG3e_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eshmTULL_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_24TvMlz8_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ov9cjqJt_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U9YCpRDI_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UsQbQe7c_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_BwhLLaeV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NqOPMZuq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_WfcAY7TU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a1qPV7rK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_pBzv2pUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0usJDJke_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Tt7xtC0z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XOjP9uGb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_6CxwiYDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qANFcugi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Hr7rDV41_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lo1SfuDs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_5KKjTfJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sIlIZUzG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_WMI6sG3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zcAoeXaG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_eshmTULL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oBG6CjZm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_24TvMlz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gDOOrRHs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ov9cjqJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GDrTAulx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_U9YCpRDI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XTMZuFLV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_UsQbQe7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UVdNsNQp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ykWyMoLz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ao4VTc2n, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ao4VTc2n_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ao4VTc2n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_FEchXAp2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_IAKfiYgt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_60JmJSYe, 0, m, &cVar_60JmJSYe_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yK5HW2gy, 0, m, &cVar_yK5HW2gy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vix1fUKo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ykWyMoLz, HV_BINOP_DIVIDE, 1, m, &cBinop_ykWyMoLz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EVJrL2jI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yK5HW2gy, 0, m, &cVar_yK5HW2gy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cN6Nzel9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_60JmJSYe, 0, m, &cVar_60JmJSYe_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NqOPMZuq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EVJrL2jI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cN6Nzel9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_a1qPV7rK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EVJrL2jI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cN6Nzel9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0usJDJke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EVJrL2jI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cN6Nzel9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XOjP9uGb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EVJrL2jI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cN6Nzel9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qANFcugi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EVJrL2jI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cN6Nzel9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lo1SfuDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EVJrL2jI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cN6Nzel9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_sIlIZUzG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EVJrL2jI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cN6Nzel9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zcAoeXaG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EVJrL2jI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cN6Nzel9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oBG6CjZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EVJrL2jI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cN6Nzel9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gDOOrRHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EVJrL2jI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cN6Nzel9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GDrTAulx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EVJrL2jI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cN6Nzel9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XTMZuFLV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EVJrL2jI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cN6Nzel9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UVdNsNQp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EVJrL2jI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cN6Nzel9_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_KJi7WrH8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N8TFvabB, HV_BINOP_DIVIDE, 0, m, &cBinop_N8TFvabB_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_yuO0Ev5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VlDOSGAL, HV_BINOP_MULTIPLY, 1, m, &cBinop_VlDOSGAL_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_RQs4WLcp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ORoUioop, 0, m, &cSlice_ORoUioop_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_AnwqnjYb, 0, m, &cSlice_AnwqnjYb_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FMoirGFj_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_R5f7nspC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_ORoUioop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_PbilmJKv, 0, m, &cVar_PbilmJKv_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_PbilmJKv, 0, m, &cVar_PbilmJKv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_AnwqnjYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_ocdcmFBs, HV_BINOP_NEQ, 1, m, &cBinop_ocdcmFBs_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_PbilmJKv, 1, m, &cVar_PbilmJKv_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_ocdcmFBs, HV_BINOP_NEQ, 1, m, &cBinop_ocdcmFBs_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_PbilmJKv, 1, m, &cVar_PbilmJKv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_PbilmJKv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_El3NlFjA_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_ZnbNOHif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H8mpUoQq_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pTxqmk47_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_pTxqmk47_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PbilmJKv, 0, m, &cVar_PbilmJKv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_H8mpUoQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ocdcmFBs, HV_BINOP_NEQ, 1, m, &cBinop_ocdcmFBs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ocdcmFBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZnbNOHif, 1, m, &cIf_ZnbNOHif_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_R5f7nspC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZnbNOHif, 0, m, &cIf_ZnbNOHif_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_FMoirGFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ocdcmFBs, HV_BINOP_NEQ, 0, m, &cBinop_ocdcmFBs_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_DG9tLeJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_trqavSDL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LlEDwQ1A_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_OKPhJ76h_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aZcoDnid_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AL1LsnAj_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OQaMiIZo_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pPbPUdgx_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2KvN92da_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3UQu8Ih9_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yx7PFeG4_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FwPBcVVQ_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zMgBRnxu_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mOX5rWcP_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iIw9AAGD_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jcPzGeJ1_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t54sRKOK_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_aZcoDnid_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OJG5zoWK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_AL1LsnAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b7p1yEXd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_OQaMiIZo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f3067WgQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_pPbPUdgx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nrOgeDPq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_2KvN92da_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QZfJFsuk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_3UQu8Ih9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aYHIT2Mu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_yx7PFeG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rF5yUp8i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_FwPBcVVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qJ6XqaXB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_zMgBRnxu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AwH9N0JM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_mOX5rWcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GD37NWbi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_iIw9AAGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gqnO6tmy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_jcPzGeJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2CCWKOzd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_t54sRKOK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rvJ4a23O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_N8TFvabB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VlDOSGAL, HV_BINOP_MULTIPLY, 0, m, &cBinop_VlDOSGAL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VlDOSGAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_RQs4WLcp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_LlEDwQ1A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KJi7WrH8, 0, m, &cVar_KJi7WrH8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yuO0Ev5b, 0, m, &cVar_yuO0Ev5b_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_trqavSDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N8TFvabB, HV_BINOP_DIVIDE, 1, m, &cBinop_N8TFvabB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_kg6WBIfV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KJi7WrH8, 0, m, &cVar_KJi7WrH8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ueI84V20_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yuO0Ev5b, 0, m, &cVar_yuO0Ev5b_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OJG5zoWK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ueI84V20_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kg6WBIfV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_b7p1yEXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ueI84V20_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kg6WBIfV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_f3067WgQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ueI84V20_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kg6WBIfV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nrOgeDPq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ueI84V20_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kg6WBIfV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QZfJFsuk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ueI84V20_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kg6WBIfV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_aYHIT2Mu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ueI84V20_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kg6WBIfV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rF5yUp8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ueI84V20_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kg6WBIfV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qJ6XqaXB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ueI84V20_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kg6WBIfV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_AwH9N0JM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ueI84V20_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kg6WBIfV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GD37NWbi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ueI84V20_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kg6WBIfV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gqnO6tmy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ueI84V20_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kg6WBIfV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2CCWKOzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ueI84V20_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kg6WBIfV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rvJ4a23O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ueI84V20_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kg6WBIfV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ff38bxvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_mk3kQezx_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_hwKEEpCW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_I3Tp0uCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_mk3kQezx_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_hwKEEpCW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_D2Xsl1p4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_mk3kQezx_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_hwKEEpCW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_FmJlTKL4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_mk3kQezx_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_hwKEEpCW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_mIaADiiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_mk3kQezx_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_hwKEEpCW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_9BBsDErZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_M099If1F, 0, m, &cVar_M099If1F_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OiPcCl2T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_cxxQrLLv, 0, m, &cVar_cxxQrLLv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_M1BElmmi, 0, m, &cVar_M1BElmmi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4CCMkPuF, 0, m, &cVar_4CCMkPuF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GuUsYa7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_vd6AaAe1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_CCKeGqRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_vd6AaAe1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_u6CICHiW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_94kfXfc5, 0, m, &cVar_94kfXfc5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ONJCVe8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_T5QgclAM, 0, m, &cVar_T5QgclAM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DMxA8Qef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0VWzsqzE, 0, m, &cVar_0VWzsqzE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_f4sA6HuQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_vd6AaAe1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Al8aaqFV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_vd6AaAe1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ah0jR9a1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_vzX2oBxM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_AxFl2K4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_vzX2oBxM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_1oZkmzC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hMkDTYQJ, 0, m, &cVar_hMkDTYQJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YtCQxxSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e6Fatjfe, 0, m, &cVar_e6Fatjfe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_n9J46MuG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lbSAm9zV, 0, m, &cVar_lbSAm9zV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rAvlWWrd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_vzX2oBxM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_l9J1bni0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_vzX2oBxM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Iw7Uf7VS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PajKgo6N_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_TE7Lfnya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PajKgo6N_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_niSZgmQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lLrbhtQi, 0, m, &cVar_lLrbhtQi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dIVNNvGy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hGaBYCEt, 0, m, &cVar_hGaBYCEt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KXUceRmO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_W4DERNiU, 0, m, &cVar_W4DERNiU_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Todhl8wM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PajKgo6N_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_P4uQsMS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PajKgo6N_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_QFJMGZXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VHTQOXFX, 0, m, &cVar_VHTQOXFX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_F0pR8j0S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FopWyqz2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ylop7rl7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OuBgZwYN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wLbzc6z1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_coG3mOCc_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wLbzc6z1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8b8XU3gr, 1, m, &cIf_8b8XU3gr_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_coG3mOCc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kmQQXUnd, 0, m, &cVar_kmQQXUnd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ylop7rl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VHTQOXFX, 0, m, &cVar_VHTQOXFX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_FopWyqz2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DUYmtJAs, 1, m, &cIf_DUYmtJAs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_flDGtR7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fAHXgocj, 0, m, &cVar_fAHXgocj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_clkshj8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_keGCzFWk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0Y5sTRN7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FTQwsRsv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tktFg5gi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cQaeNCmV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tktFg5gi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1z4OrrVx, 1, m, &cIf_1z4OrrVx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cQaeNCmV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wLiHOiSv, 0, m, &cVar_wLiHOiSv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0Y5sTRN7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fAHXgocj, 0, m, &cVar_fAHXgocj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_keGCzFWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yoSjmVvg, 1, m, &cIf_yoSjmVvg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_El3NlFjA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LwxuYIQx, 0, m, &cVar_LwxuYIQx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CtkFcFIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_70NG6LgY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_onT1xJK9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VJN192wg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AQ4c4FWq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_16iXzkaW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_16iXzkaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Pdwn4J3F, 0, m, &cVar_Pdwn4J3F_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_AQ4c4FWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T1r9vE6w, 1, m, &cIf_T1r9vE6w_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_onT1xJK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LwxuYIQx, 0, m, &cVar_LwxuYIQx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_70NG6LgY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ho6LZp4F, 1, m, &cIf_Ho6LZp4F_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_pu2NoPBG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cxxQrLLv, 0, m, &cVar_cxxQrLLv_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_qCmM9SR6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_M1BElmmi, 0, m, &cVar_M1BElmmi_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_iYe1Ziz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4CCMkPuF, 0, m, &cVar_4CCMkPuF_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_xYyoMlcg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6fse0yqs, 0, m, &cVar_6fse0yqs_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_LHmAyIjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vfHJPO9m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_73rNq49A_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_hbh2o6hq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u2P7FlRF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KxErxoS9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FurvL8FG_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_CspsPfOP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4D99cDom_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ircxo2Zv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t0u993e4_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_XP7CqH2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ayLqH03L_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_To0AhPEt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NRdocnMv_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_VHfEqECx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VqCS5uRP_sendMessage(_c, 0, m);
  cMsg_Jvj7e1fe_sendMessage(_c, 0, m);
  cMsg_dDjmhAEM_sendMessage(_c, 0, m);
  cMsg_Z6EDQVRX_sendMessage(_c, 0, m);
  cMsg_rElxTpIf_sendMessage(_c, 0, m);
  cMsg_08Cnv8Z3_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_8RY5oQ5q, 0, m, &cVar_8RY5oQ5q_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6fse0yqs, 0, m, &cVar_6fse0yqs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_m2MMB7lY, 0, m, &cVar_m2MMB7lY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dbniPqPi, 0, m, &cVar_dbniPqPi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OcT4AKvb, 0, m, &cVar_OcT4AKvb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aWiIfSwa, 0, m, &cVar_aWiIfSwa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DCAGpsrt, 0, m, &cVar_DCAGpsrt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mQZfrxjo, 0, m, &cVar_mQZfrxjo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_n6WLH7zP, 0, m, &cVar_n6WLH7zP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XUYoBd2C, 0, m, &cVar_XUYoBd2C_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SI82aWPG, 0, m, &cVar_SI82aWPG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GNuuymJh, 0, m, &cVar_GNuuymJh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Z3k4yrjR, 0, m, &cVar_Z3k4yrjR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DWSAn3xD, 0, m, &cVar_DWSAn3xD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6RiZ01OC, 0, m, &cVar_6RiZ01OC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mXCCbJU8, 0, m, &cVar_mXCCbJU8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ds3Y0ZbT, 0, m, &cVar_ds3Y0ZbT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_eEkNIBET, 0, m, &cVar_eEkNIBET_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pfN4GjrM, 0, m, &cVar_pfN4GjrM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ittQyS7t, 0, m, &cVar_ittQyS7t_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_P9pvGXEH, 0, m, &cVar_P9pvGXEH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WArCMriK, 0, m, &cVar_WArCMriK_sendMessage);
  cMsg_K2zOvOUI_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Hx7wVEbO, 0, m, &cVar_Hx7wVEbO_sendMessage);
  cMsg_ZDQZuOv3_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_8f3Pqlc4, 0, m, &cVar_8f3Pqlc4_sendMessage);
  cMsg_cggSMTWu_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_06Jdk9i8, 0, m, &cVar_06Jdk9i8_sendMessage);
  cMsg_s8Wb6DHj_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_79mHy3TD, 0, m, &cVar_79mHy3TD_sendMessage);
  cMsg_Ow8tcuQ0_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_X4B58Xcp, 0, m, &cVar_X4B58Xcp_sendMessage);
  cMsg_Y74Z3VZF_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_a8WDOYXA, 0, m, &cVar_a8WDOYXA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mETmPcNZ, 0, m, &cVar_mETmPcNZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xkyb6vYx, 0, m, &cVar_xkyb6vYx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GHhzdfso, 0, m, &cVar_GHhzdfso_sendMessage);
  cMsg_3drEDnsv_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_T8mSP6iT, 0, m, &cVar_T8mSP6iT_sendMessage);
  cMsg_A8CTrdcl_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_bhwpJze7, 0, m, &cVar_bhwpJze7_sendMessage);
  cMsg_fKFrb83B_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_m99HuQL2, 0, m, &cVar_m99HuQL2_sendMessage);
  cMsg_qeMHxGyV_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_8gafSZCk, 0, m, &cVar_8gafSZCk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_s9NX3qqo, 0, m, &cVar_s9NX3qqo_sendMessage);
  cMsg_YC47Gt28_sendMessage(_c, 0, m);
  cMsg_rGR1wQtr_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ojruipJx, 0, m, &cVar_ojruipJx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aP6sP9Af, 0, m, &cVar_aP6sP9Af_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aCG7YvSd, 0, m, &cVar_aCG7YvSd_sendMessage);
  cMsg_ZyJrJ6GB_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_IxkAjUtR, 0, m, &cVar_IxkAjUtR_sendMessage);
  cMsg_GC80J98l_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_T6BQO7pv, 0, m, &cVar_T6BQO7pv_sendMessage);
  cMsg_fXlQmrmP_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_5wHoJyT6, 0, m, &cVar_5wHoJyT6_sendMessage);
  cMsg_3cpvwJok_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_G6DZUdJX, 0, m, &cVar_G6DZUdJX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FEBZkrUM, 0, m, &cVar_FEBZkrUM_sendMessage);
  cMsg_L4lqoUqc_sendMessage(_c, 0, m);
  cMsg_m65gghvY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_z3nozhED, 0, m, &cVar_z3nozhED_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8ta5rOTh, 0, m, &cVar_8ta5rOTh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ennIrtAO, 0, m, &cVar_ennIrtAO_sendMessage);
  cMsg_bmkgH7EF_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_wETjFAOW, 0, m, &cVar_wETjFAOW_sendMessage);
  cMsg_wkugLWtY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_U3tCEwTp, 0, m, &cVar_U3tCEwTp_sendMessage);
  cMsg_YAxusiPm_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_gI6eCAop, 0, m, &cVar_gI6eCAop_sendMessage);
  cMsg_hc7kfRh8_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_khRxwZYA, 0, m, &cVar_khRxwZYA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OGdAaZmD, 0, m, &cVar_OGdAaZmD_sendMessage);
  cMsg_y0WFTjSI_sendMessage(_c, 0, m);
  cMsg_7vjoAodb_sendMessage(_c, 0, m);
  cMsg_OiPcCl2T_sendMessage(_c, 0, m);
  cMsg_9BBsDErZ_sendMessage(_c, 0, m);
  cMsg_Gu3uVJMt_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_rg6DXSsy, 0, m, &cVar_rg6DXSsy_sendMessage);
  cMsg_rYJVR5iT_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_gJx0X160, 0, m, &cTabhead_gJx0X160_sendMessage);
  cMsg_afH1FZHv_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_6UmO9q3a, 0, m, &cVar_6UmO9q3a_sendMessage);
  cMsg_22boBTwR_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_o948jWOb, 0, m, &cTabhead_o948jWOb_sendMessage);
  cMsg_pYIvUrNw_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_HwvrKiZy, 0, m, &cVar_HwvrKiZy_sendMessage);
  cMsg_1HhWRUDo_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_2pTjEii2, 0, m, &cTabhead_2pTjEii2_sendMessage);
  cMsg_XfkJg9gf_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_jMqXPRBZ, 0, m, &cVar_jMqXPRBZ_sendMessage);
  cMsg_n4niBbml_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_FUifxdjL, 0, m, &cTabhead_FUifxdjL_sendMessage);
  cMsg_WjyK5a9G_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_BQDWME4k, 0, m, &cVar_BQDWME4k_sendMessage);
  cMsg_qIAt7pbh_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ykw58UG0, 0, m, &cTabhead_ykw58UG0_sendMessage);
  cMsg_t432WEtl_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_tKu2rfdg, 0, m, &cVar_tKu2rfdg_sendMessage);
  cMsg_IUnuRkzG_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_3g3CQxeW, 0, m, &cTabhead_3g3CQxeW_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Nf01sc3Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LmoUtc4k, HV_BINOP_MULTIPLY, 0, m, &cBinop_LmoUtc4k_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_MeacDDta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_dosVlFdl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_S6arLEky_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_gYmf1KHt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_aoTOluNs_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_moFlU1mO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_QUAy1bdB_sendMessage);
  cMsg_UBNRkf7W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_DY7VUTfA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JfndkYEu, HV_BINOP_MULTIPLY, 0, m, &cBinop_JfndkYEu_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_wQjsqamu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_Tbyyc5Jh_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Jrgh0QzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_51ekKGyS, HV_BINOP_MULTIPLY, 1, m, &cBinop_51ekKGyS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_vIo7jR81_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_JPRFS4XN_sendMessage);
  cMsg_wD4QZody_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_qqaNsAcw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BxrOejqu, HV_BINOP_MULTIPLY, 0, m, &cBinop_BxrOejqu_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Tb36u82i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ofhWDUwo_sendMessage(_c, 0, m);
  cMsg_9uacLuiz_sendMessage(_c, 0, m);
  cMsg_HZjYQ9BO_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_6k7ddLKz_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_i3yNzgeI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_4CIWX4bz_sendMessage);
  cMsg_28d9FChS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_QYwrIzxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OcT4AKvb, 0, m, &cVar_OcT4AKvb_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_anGDLL73_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fNJ9Wr56_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mL20tTNX_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_1iChQWl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f0LImA3i_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3bJiWD0M_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pI7UG4ZH_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_NinU2bsY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zx9VVAmZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2AqRguPk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Rgmsmtcu_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_tQHMpFjK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XnihG6tC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PUzTOcdv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DWOTawss_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_5NBDj3wk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p0MimApN, HV_BINOP_MULTIPLY, 0, m, &cBinop_p0MimApN_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_SWBJm4AX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_CMGFRSFt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ZqfzCj9c_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_GsnLs2Vp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_Z7YEHmGq_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_sj19YkBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Mb4TD4Jv_sendMessage);
  cMsg_XVnM42Ry_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_VLnWl3lw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UaNq6Kvq, HV_BINOP_MULTIPLY, 0, m, &cBinop_UaNq6Kvq_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_K0R5fp0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_l5sW4Sa7_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Q5yKSL6P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xkW1VZvY, HV_BINOP_MULTIPLY, 1, m, &cBinop_xkW1VZvY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_vwrROOoO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_kphcoe6K_sendMessage);
  cMsg_mLvehn2K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_tFWWhnEU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dVlqQS01, HV_BINOP_MULTIPLY, 0, m, &cBinop_dVlqQS01_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_oVtv3ZMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m4A2LWcO_sendMessage(_c, 0, m);
  cMsg_lpgZw9EZ_sendMessage(_c, 0, m);
  cMsg_hXthcvxt_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_dsoUQWyR_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_5whLPSVi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_NtI6Y4kQ_sendMessage);
  cMsg_MJI9XsWH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_r26P1mbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_M099If1F, 0, m, &cVar_M099If1F_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_caLDETxu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_u6CICHiW_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Dxyr87GA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ONJCVe8x_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_2EiNnxcf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_DMxA8Qef_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_m8sXm888_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_1oZkmzC7_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_4J07busq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_YtCQxxSV_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_gwKD8tF1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_niSZgmQX_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_dBO79Iav_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_dIVNNvGy_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_yhdjANac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_KXUceRmO_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_eo61LnEd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_n9J46MuG_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_XomccZhE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0vHEpVN8, HV_BINOP_MULTIPLY, 1, m, &cBinop_0vHEpVN8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tAIOoZfu_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mtq9595T, HV_BINOP_MULTIPLY, 1, m, &cBinop_mtq9595T_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dIoK9Ch9_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_dPx8wTm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_fU6PD9Tj, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_MKbXnxjZ, m);
}

void Heavy_WSTD_DL3Y::cReceive_ZvnMWcNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_zrbkqJqi_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_xkF4puXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_c5wDnJmP_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_t02eVlBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WvArmTSc, HV_BINOP_MULTIPLY, 1, m, &cBinop_WvArmTSc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N5684Gc1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3keyEG44, HV_BINOP_MULTIPLY, 1, m, &cBinop_3keyEG44_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0OnoMTLz_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_nxasNClf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_RUl9SJo5, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_7wyCy6c9, m);
}

void Heavy_WSTD_DL3Y::cReceive_0uNx3bey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_H8MzQh0j_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_wv7AMngu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Kgcs0uuM_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_9gNJyThY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0BGtaNGi, HV_BINOP_MULTIPLY, 1, m, &cBinop_0BGtaNGi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8X0I6Q9j_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_U557CEPr, HV_BINOP_MULTIPLY, 1, m, &cBinop_U557CEPr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LjtJX1eB_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_TJD4nbWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_3Kgcf9t5, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_KGd2UF1k, m);
}

void Heavy_WSTD_DL3Y::cReceive_9HRPrj22_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_eGXbEPn3_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_F3Li0fNB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_LLUfySdV_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Q1JYv1GU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kmQQXUnd, 0, m, &cVar_kmQQXUnd_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_xZALtXPv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pRG0OfjE, 0, m, &cVar_pRG0OfjE_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ORRH7ss3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CCRFu9ju, 0, m, &cVar_CCRFu9ju_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_sfDctFH1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wLiHOiSv, 0, m, &cVar_wLiHOiSv_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_WBG84f72_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Pdwn4J3F, 0, m, &cVar_Pdwn4J3F_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_J9UxkRUV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_S4gmapW3, 0, m, &cVar_S4gmapW3_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_lfhBGKcU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CCbN6szz, 0, m, &cVar_CCbN6szz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nUlc5jzB, 0, m, &cVar_nUlc5jzB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DG9tLeJV, 0, m, &cVar_DG9tLeJV_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_aXaphhfq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YR5Jsy5B_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_uIliMSUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Quu3yEGN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_jYsnJT2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_OKPhJ76h_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DL3Y::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_2oA7sfgm, VOf(Bf0));
    __hv_line_f(&sLine_TuY09ETd, VOf(Bf1));
    __hv_line_f(&sLine_IhnTv8SQ, VOf(Bf2));
    __hv_line_f(&sLine_yE9H23On, VOf(Bf3));
    __hv_line_f(&sLine_Q9FHUFOi, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_4QgyLqtB, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_jwVmV3J4, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_NCEp5pmf, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_Ep6UuHZl, VOf(Bf1));
    __hv_line_f(&sLine_pI6D5OD0, VOf(Bf0));
    __hv_line_f(&sLine_rMu40C5n, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_tzcFH2Gv, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_vrczjGTs, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_593uHNv0, VOf(Bf5));
    __hv_line_f(&sLine_twYcT8JJ, VOf(Bf1));
    __hv_line_f(&sLine_38198bpS, VOf(Bf2));
    __hv_line_f(&sLine_0Nt6SWVX, VOf(Bf4));
    __hv_line_f(&sLine_b3c8LHzh, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_G5nYmyjp, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_T4VZ0KYY, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_E2Gpf6sL, VOf(Bf6));
    __hv_line_f(&sLine_HiuaC8y2, VOf(Bf2));
    __hv_line_f(&sLine_bvFDyvHj, VOf(Bf1));
    __hv_line_f(&sLine_0MKEaSrz, VOf(Bf5));
    __hv_line_f(&sLine_dTwWljtH, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_Wo6E04Vt, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_jDCQyZo4, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_M6v7dLaC, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_3q34eYtg, VOf(Bf2));
    __hv_line_f(&sLine_NVKNfUn9, VOf(Bf6));
    __hv_line_f(&sLine_qOgan6NH, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_LSKdzBzM, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_V4kp1T7G, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_WkngJ3XO, VOf(Bf8));
    __hv_line_f(&sLine_xZqgTfuT, VOf(Bf2));
    __hv_line_f(&sLine_1FHfXI1L, VOf(Bf1));
    __hv_line_f(&sLine_NBRfdjRL, VOf(Bf7));
    __hv_line_f(&sLine_JSqxpaNw, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_pUCSPQWX, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_Zi9H2KQy, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_bLCuxmoW, VOf(Bf9));
    __hv_tabread_f(&sTabread_yLdSjCoK, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_utSKmGDg, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_wfxUkuYD, VOf(Bf9));
    __hv_tabread_f(&sTabread_jTcBTZVp, VOf(Bf8));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_Twvj8aKn, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_zEA4zm8f, VOf(Bf9));
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_CSIs9fAK, VOf(Bf3));
    __hv_rpole_f(&sRPole_mVWAUj7v, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_4WS56Rl5, VIf(Bf3), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_HM6GvIZJ, VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_PZ0ghr0m, VIf(Bf3));
    __hv_varread_f(&sVarf_P1YMH5Wi, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_tQiURUs4, VOf(Bf5));
    __hv_rpole_f(&sRPole_EcWtrgoa, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_8FaApGNr, VIf(Bf5), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_qIxhJsgt, VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_WF3ks5yU, VIf(Bf5));
    __hv_varread_f(&sVarf_fU6PD9Tj, VOf(Bf5));
    __hv_mul_f(VIf(Bf1), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_4IuQTbbn, VOf(Bf1));
    __hv_varread_f(&sVarf_MKbXnxjZ, VOf(Bf3));
    __hv_mul_f(VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_iHsKI804, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_INsMxYSg, VOf(Bf1));
    __hv_varread_f(&sVarf_71QveUuE, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_wa34A2tM, VOf(Bf1));
    __hv_rpole_f(&sRPole_1oFsDUID, VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_4qogAbA2, VIf(Bf8), &sEnv_4qogAbA2_sendMessage);
    __hv_varread_f(&sVarf_YMO7IlEL, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_ljKnGqT9, VOf(Bf1));
    __hv_rpole_f(&sRPole_uUWeBaaJ, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_zEA4zm8f, VIf(Bf1));
    __hv_line_f(&sLine_IQ7inc5L, VOf(Bf1));
    __hv_line_f(&sLine_oGq0VDwP, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_pn9tKd06, VOf(Bf1));
    __hv_varread_f(&sVarf_pmMLYMUx, VOf(Bf3));
    __hv_mul_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_GMP0WMNK, VOf(Bf1));
    __hv_rpole_f(&sRPole_Cud2Lm2t, VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_K4IbXxoc, VIf(Bf8), &sEnv_K4IbXxoc_sendMessage);
    __hv_varread_f(&sVarf_PDhT2aip, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_v0ldGHEL, VOf(Bf1));
    __hv_rpole_f(&sRPole_J4RXl7aQ, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_P1YMH5Wi, VIf(Bf1));
    __hv_varwrite_f(&sVarf_A21pHe27, VIf(Bf2));
    __hv_varread_f(&sVarf_dZ936Rpt, VOf(Bf2));
    __hv_varread_f(&sVarf_v6j5S1Fz, VOf(Bf1));
    __hv_line_f(&sLine_8iVM7Tlz, VOf(Bf8));
    __hv_tabread_f(&sTabread_mvrlFkTa, VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_Fb3CgQop, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf2), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_MMX20r1Q, VOf(Bf8));
    __hv_tabread_f(&sTabread_bq6wfG3C, VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_tD2vcfSh, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf1), VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_bofiRoCj, VOf(Bf8));
    __hv_add_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_PKwPEX0I, VOf(Bf2));
    __hv_rpole_f(&sRPole_pbZ8NXDL, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_Hfm0T8aS, VIf(Bf2), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_sub_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_HvySZ8kd, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_tabwrite_f(&sTabwrite_6jewWSxb, VIf(Bf2));
    __hv_varread_f(&sVarf_2ehm8OhQ, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_cGNxohQa, VOf(Bf1));
    __hv_rpole_f(&sRPole_S8KxYp5s, VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_svi7Odcn, VIf(Bf1), VOf(Bf8));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_K2hlnLN3, VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_xqQF5wro, VIf(Bf1));
    __hv_varread_f(&sVarf_RUl9SJo5, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_miEqcGzl, VOf(Bf3));
    __hv_varread_f(&sVarf_7wyCy6c9, VOf(Bf2));
    __hv_mul_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_kJnqDVux, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf1), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_2cH5tQpI, VOf(Bf3));
    __hv_varread_f(&sVarf_oroFNGcd, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_jIJJgEol, VOf(Bf3));
    __hv_rpole_f(&sRPole_4fd8yj2X, VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_UKnxZEUt, VIf(Bf9), &sEnv_UKnxZEUt_sendMessage);
    __hv_varread_f(&sVarf_j1bSQNEb, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_2XIPchpG, VOf(Bf3));
    __hv_rpole_f(&sRPole_KnLzsVKf, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_bofiRoCj, VIf(Bf3));
    __hv_line_f(&sLine_Bnrp9H72, VOf(Bf3));
    __hv_line_f(&sLine_jaKaOK2j, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_ceX3I6Pm, VOf(Bf3));
    __hv_varread_f(&sVarf_apWh2XYR, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_yFeKyiFF, VOf(Bf3));
    __hv_rpole_f(&sRPole_LWgkhv6F, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_9KD2wR6y, VIf(Bf9), &sEnv_9KD2wR6y_sendMessage);
    __hv_varread_f(&sVarf_fQAyb3if, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_t9J0x4Lq, VOf(Bf3));
    __hv_rpole_f(&sRPole_mb7JcPub, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_2ehm8OhQ, VIf(Bf3));
    __hv_varwrite_f(&sVarf_NJ1KRqDS, VIf(Bf5));
    __hv_varread_f(&sVarf_v4k8uZS7, VOf(Bf5));
    __hv_varread_f(&sVarf_bNeGPnx2, VOf(Bf3));
    __hv_line_f(&sLine_URkDQfHZ, VOf(Bf9));
    __hv_tabread_f(&sTabread_dlR63vCu, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_eOJnaWpJ, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_IqdsTprS, VOf(Bf9));
    __hv_tabread_f(&sTabread_99Js78VF, VOf(Bf8));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_Fkm2zs7P, VOf(Bf12));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_0C1haSB8, VOf(Bf9));
    __hv_add_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_jmd58Q9e, VOf(Bf5));
    __hv_rpole_f(&sRPole_vuxVlLff, VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_UpuHiHui, VIf(Bf5), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_I5IjzmZh, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_zFlFCvWn, VIf(Bf5));
    __hv_varread_f(&sVarf_3QKCgs2s, VOf(Bf5));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_CHIUgKtc, VOf(Bf3));
    __hv_rpole_f(&sRPole_mj1o6jcU, VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_ihbWM3u9, VIf(Bf3), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_5kqZopWZ, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_VXpSlNKB, VIf(Bf3));
    __hv_varread_f(&sVarf_3Kgcf9t5, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_0OcbbiF9, VOf(Bf2));
    __hv_varread_f(&sVarf_KGd2UF1k, VOf(Bf5));
    __hv_mul_f(VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_fLPL752l, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_E8WGpvdP, VOf(Bf2));
    __hv_varread_f(&sVarf_FkJRdlvA, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_IZBsLiYf, VOf(Bf2));
    __hv_rpole_f(&sRPole_BXVafAk2, VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_jtn9H55R, VIf(Bf8), &sEnv_jtn9H55R_sendMessage);
    __hv_varread_f(&sVarf_6N9xixoS, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_Ppdm7b6C, VOf(Bf2));
    __hv_rpole_f(&sRPole_xMqUgu9F, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_0C1haSB8, VIf(Bf2));
    __hv_line_f(&sLine_x7HYKtqm, VOf(Bf2));
    __hv_line_f(&sLine_mgVqi2NH, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_TPjdyPHS, VOf(Bf2));
    __hv_varread_f(&sVarf_4MgL4vKE, VOf(Bf5));
    __hv_mul_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_9oIIFQlZ, VOf(Bf2));
    __hv_rpole_f(&sRPole_c9OVUOot, VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_4e45RP5Y, VIf(Bf8), &sEnv_4e45RP5Y_sendMessage);
    __hv_varread_f(&sVarf_0LbwuWxx, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_2nTN6fGk, VOf(Bf2));
    __hv_rpole_f(&sRPole_hzYACccr, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_3QKCgs2s, VIf(Bf2));
    __hv_varwrite_f(&sVarf_rG4lDGZP, VIf(Bf1));
    __hv_varwrite_f(&sVarf_n7vtT88R, VIf(Bf10));
    __hv_varwrite_f(&sVarf_XAc2Lnuu, VIf(Bf11));
    __hv_varwrite_f(&sVarf_KQSv8Cir, VIf(Bf12));
    __hv_varwrite_f(&sVarf_dZ936Rpt, VIf(Bf0));
    __hv_varwrite_f(&sVarf_v6j5S1Fz, VIf(Bf6));
    __hv_varwrite_f(&sVarf_v4k8uZS7, VIf(Bf4));
    __hv_varwrite_f(&sVarf_bNeGPnx2, VIf(Bf7));
    __hv_varread_f(&sVarf_A21pHe27, VOf(Bf7));
    __hv_varread_f(&sVarf_NJ1KRqDS, VOf(Bf4));
    __hv_varread_f(&sVarf_rG4lDGZP, VOf(Bf6));
    __hv_add_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_n7vtT88R, VOf(Bf6));
    __hv_varread_f(&sVarf_XAc2Lnuu, VOf(Bf7));
    __hv_varread_f(&sVarf_KQSv8Cir, VOf(Bf4));
    __hv_add_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf4), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DL3Y::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DL3Y::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
